#
# spec file
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __python %{__python3}
%global with_guestfs               0
%global default_hvs                "qemu,xen,lxc"
%if 0%{?suse_version} < 1600 || 0%{?suse_version} >= 1699
    %define is_sles16 0
    %define have_spice 1
%else
    %define is_sles16 1
    %define have_spice 0
%endif

%global flavor %{nil}
# No spice on SLES16 so no running check build
%if "%{flavor}" == "test" && %{have_spice}
%bcond_without test
%define psuffix -%{flavor}
%else
%bcond_with test
%define psuffix %{nil}
%endif

Name:           virt-manager%{psuffix}
Version:        5.0.0
Release:        10.1
Summary:        Virtual Machine Manager
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            http://virt-manager.org/
Source0:        https://releases.pagure.org/virt-manager/virt-manager-%{version}.tar.xz
Source1:        virt-install.rb
Source2:        virt-install.desktop
Source3:        virt-manager-supportconfig
# Upstream Patches
Patch1:         001-cli-Support-cpu-maximum.patch
Patch2:         002-gui-Support-maximum-CPU-mode.patch
Patch3:         003-cpu-Prefer-maximum-mode-for-many-emulated-guests.patch
Patch4:         004-domcaps-get-list-of-supported-panic-device-models.patch
Patch5:         005-tests-Update-capabilities-for-advertisting-panic-device-models.patch
Patch6:         006-addhardware-panic-Fill-in-model-combo-with-advertised-values-by-libvirt.patch
Patch7:         007-cli-man-Always-list-osinfo-before-os-variant.patch
Patch8:         008-snapshots-default-to-same-snapshot-mode-as-currently-used-snapshot.patch
Patch9:         009-snapshots-warn-users-to-not-mix-snapshot-modes.patch
Patch10:        010-virtManager-domain-fix-indentation.patch
Patch21:        021-cli-Add-memdev-target.dynamicMemslots-support-for-virtio-mem.patch
Patch22:        022-cli-add-target.memReserve-for-pci-bridge-and-pcie-root-port-controllers.patch
Patch23:        023-cli-Add-disk-driver.queue_size-support.patch
Patch24:        024-cli-Add-poll-settings-for-iothread.patch
Patch25:        025-test_cli-Fix-a-pycodestyle-E261-issue.patch
Patch26:        026-gitignore-Ignore-coverage.xml.patch
Patch27:        027-cli-Add-tpm-backend.profile.source-removeDisabled-support.patch
Patch28:        028-cli-Add-nvram.templateFormat-to-indicate-template-format.patch
Patch29:        029-cli-Add-features-hyperv.xmm_input.state-on-off.patch
Patch30:        030-cli-Add-features-hyperv.emsr_bitmap.state-on-off.patch
Patch31:        031-cli-Add-features-hyperv.tlbflush.direct.state-on-off.patch
Patch32:        032-cli-Add-features-hyperv.tlbflush.extended.state-on-off.patch
Patch33:        033-createvm-prioritize-riscv64.patch
Patch34:        034-tests-uitests-handle-linux2020-going-EOL.patch
Patch40:        040-virtinst-add-pstore-backend-support.patch
Patch41:        041-tests-add-pstore-test.patch
Patch42:        042-man-virt-install-Document-pstore-device.patch
Patch43:        043-tests-Increase-virtio-mem-block-size.patch
Patch44:        044-tests-test_urls-fix-dead-URL.patch
Patch45:        045-urlfetcher-add-riscv64-architecture-for-Debian.patch
Patch46:        046-virt-manager-list-virtual-networks-when-creating-new-QEMU-Session-VM.patch
Patch47:        047-virt-install-add-support-for-vDPA-network-device.patch
Patch48:        048-virt-manager-add-support-for-vDPA-network-device.patch
Patch49:        049-virt-install-detect-wayland-in-order-to-start-virt-viewer.patch
Patch100:       revert-363fca41-virt-install-Require-osinfo-for-non-x86-HVM-case-too.patch
# SUSE Only
Patch150:       virtman-desktop.patch
Patch151:       virtman-kvm.patch
Patch152:       virtman-show-suse-install-repos.patch
Patch153:       virtman-dont-allow-grub.xen-to-be-deleted.patch
Patch154:       virtinst-pvgrub2-bootloader.patch
Patch155:       virtinst-change-location-for-grub_xen.patch
Patch156:       virtinst-set-qemu-emulator.patch
# Features or Enhancements
Patch203:       virtman-load-stored-uris.patch
Patch204:       virtman-add-tooltip-to-firmware.patch
Patch205:       virtman-modify-gui-defaults.patch
Patch206:       virtman-add-sev-memory-support.patch
Patch220:       virtinst-default-xen-to-qcow2-format.patch
Patch221:       virtinst-detect-oes-distros.patch
Patch222:       virtinst-vol-default-nocow.patch
Patch223:       virtinst-set-cache-mode-unsafe-for-install.patch
Patch224:       virtinst-s390x-disable-graphics.patch
Patch225:       virtinst-add-caasp-support.patch
Patch226:       virtinst-add-sle15-detection-support.patch
Patch227:       virtinst-media-detection.patch
# Bug Fixes
Patch251:       virtman-increase-setKeepAlive-count.patch
Patch252:       virtman-allow-destroy-from-shutdown-menu-of-crashed-vm.patch
Patch253:       virtman-allow-creating-i686-vm.patch
Patch254:       virtman-dont-specify-vte-version.patch
Patch255:       virtman-fix-restore-vm-menu-selection.patch
Patch256:       virtman-disallow-adding-floppy-disk.patch
Patch257:       virtman-register-delete-event-for-details-dialog.patch
Patch258:       virtman-revert-use-of-AyatanaAppIndicator3.patch
Patch259:       virtman-fix-inspection-apps-window.patch
Patch260:       virtman-fix-shared-disk-request-alignment-error.patch
Patch270:       virtinst-xen-drive-type.patch
Patch271:       virtinst-xenbus-disk-index-fix.patch
Patch272:       virtinst-refresh_before_fetch_pool.patch
Patch273:       virtinst-use-xenpae-kernel-for-32bit.patch
Patch274:       virtinst-use-qemu-for-cdrom-device.patch
Patch275:       virtinst-keep-install-iso-attached.patch
Patch277:       virtinst-set-default-nic.patch
Patch278:       virtinst-sap-detection.patch
Patch279:       virtinst-smbios-unsupported-for-xenpv.patch
Patch280:       virtinst-keep-iso-for-xenpv.patch
Patch281:       virtinst-add-slem-detection-support.patch
Patch282:       virtinst-add-sle-hpc-support.patch
Patch283:       virtinst-add-oracle-linux-support.patch
Patch284:       virtinst-add-slem60-detection-support.patch
Patch285:       virtinst-windows-server-detection.patch
Patch286:       virtinst-drop-removeprefix-usage.patch
Patch287:       virtinst-add-sle16-detection-support.patch
Patch288:       virtinst-dont-require-uefi-for-sev-snp.patch

BuildArch:      noarch

%define verrel %{version}-%{release}
Requires:       dconf
Requires:       gtk3
Requires:       python3-gobject
Requires:       virt-manager-common = %{verrel}
Requires:       vte

Recommends:     gtksourceview4
Recommends:     libvirt-daemon-config-network
Recommends:     (libvirt-daemon-kvm or libvirt-daemon-qemu)

Suggests:       python3-libguestfs

BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  python3-devel
BuildRequires:  python3-docutils
BuildRequires:  pkgconfig(gobject-introspection-1.0)
%if %{is_sles16}
%define __requires_exclude typelib\\(AppIndicator3|SpiceClientGtk|SpiceClientGLib|GtkSource\\) = 3.0
%else
# GtkSource = 4 is available everywhere we run this version of virt-manager
%define __requires_exclude typelib\\(GtkSource\\) = 3.0
%endif
%if %{with test}
BuildRequires:  python3-argcomplete
BuildRequires:  python3-pytest
BuildRequires:  virt-install = %{version}
BuildRequires:  virt-manager = %{version}
BuildRequires:  pkgconfig(vte-2.91)
%endif

%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and QEmu. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.

%package common
Summary:        Common files used by the different Virtual Machine Manager interfaces
Group:          System/Monitoring

# This version not strictly required: virt-manager should work with older,
# however varying amounts of functionality will not be enabled.
Requires:       libosinfo >= 0.2.10
Requires:       python3-argcomplete
Requires:       python3-gobject
Requires:       python3-libvirt-python >= 0.7.0
Requires:       python3-libxml2-python
Requires:       python3-requests
Requires:       xorriso

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.

%package -n virt-install
Summary:        Utilities for installing virtual machines
Group:          System/Monitoring

Requires:       libvirt-client
Requires:       virt-manager-common = %{verrel}

Provides:       python3-virtinst
Provides:       virt-clone
Provides:       virt-xml
Supplements:    virt-manager

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).

%prep
%autosetup -p1 -n virt-manager-%{version}

%if !%{with test}
%build
%if %{default_hvs}
%global _default_hvs --default-hvs %{default_hvs}
%endif
%if %{have_spice}
%global _default_graphics -Ddefault-graphics=spice
%else
%global _default_graphics -Ddefault-graphics=vnc
%endif
%meson \
    -Ddefault-hvs=%{default_hvs} \
    %{?_default_graphics} \
    -Dupdate-icon-cache=false \
    -Dcompile-schemas=false \
    -Dtests=disabled
%meson_build

%install
%meson_install

# YaST is not used on SLES16
%if ! %{?is_sles16}
mkdir -p %{buildroot}/%{_datadir}/YaST2/clients/
install -m644 %SOURCE1 %{buildroot}/%{_datadir}/YaST2/clients/virt-install.rb
mkdir -p %{buildroot}/%{_datadir}/applications/YaST2/
install -m644 %SOURCE2 %{buildroot}/%{_datadir}/applications/YaST2/virt-install.desktop
%endif
# Oddly, supportconfig doesn't execute plugins with '-' in the name, so use 'virt_manager'
mkdir -p %{buildroot}/usr/lib/supportconfig/plugins
install -m 755 %SOURCE3 %{buildroot}/usr/lib/supportconfig/plugins/virt_manager
chmod -x %{buildroot}%{_datadir}/virt-manager/virtManager/virtmanager.py

%python3_fix_shebang

%find_lang %{name}
%endif

%if %{with test}
%check
# TODO: check if these are genuine failures or due to the non-upstream patches
# different device names
donttest="test_disk_numtotarget"
donttest="$donttest or testCLI0001virt_install_many_devices"
donttest="$donttest or testCLI0003virt_install_singleton_config_2"
donttest="$donttest or testCLI0004virt_install_singleton_config_2"
donttest="$donttest or testCLI0101virt_install_cloud_init_default"
donttest="$donttest or testCLI0101virt_install_cloud_init_options1"
donttest="$donttest or testCLI0102virt_install_cloud_init_options1"
donttest="$donttest or testCLI0113virt_install_reinstall_cdrom"
donttest="$donttest or testCLI0117virt_install_reinstall_cdrom"
donttest="$donttest or testCLI0147virt_install_win11"
donttest="$donttest or testCLI0147virt_install_win11_no_uefi"
donttest="$donttest or testCLI0148virt_install_win11_no_uefi"
donttest="$donttest or testCLI0151virt_install_location_iso_and_cloud_init"
donttest="$donttest or testCLI0165virt_install"
donttest="$donttest or testCLI0173virt_install"
donttest="$donttest or testCLI0172virt_install_s390x_cdrom"
donttest="$donttest or testCLI0180virt_install_s390x_cdrom"
donttest="$donttest or testCLI0186virt_install_riscv64_cloud_init"
donttest="$donttest or testCLI0187virt_install_riscv64_cdrom"
donttest="$donttest or testCLI0188virt_install_riscv64_unattended"
donttest="$donttest or testCLI0200virt_install_aarch64_cloud_init"
donttest="$donttest or testCLI0204virt_install_loongarch64_cloud_init"
donttest="$donttest or testCLI0205virt_install_loongarch64_cdrom"
donttest="$donttest or testCLI0206virt_install_loongarch64_unattended"
donttest="$donttest or testCLI0193virt_install_xen_default"
donttest="$donttest or testCLI0216virt_install_xen_default"
donttest="$donttest or testCLI0217virt_install_xenpvh"
donttest="$donttest or testCLI0218virt_install_xen_pv"
donttest="$donttest or testCLI0219virt_install_xen_hvm"
donttest="$donttest or testCLI0220virt_install_xen_hvm"
donttest="$donttest or testCLI0227virt_install_bhyve_default_f27"
donttest="$donttest or testCLI0307virt_xml_build_disk_domain"
donttest="$donttest or testCLI0315virt_xml_edit_cpu_host_copy"
donttest="$donttest or testCLI0316virt_xml_build_pool_logical_disk"
donttest="$donttest or testCLI0416virt_xml_add_disk_create_storage_start"
donttest="$donttest or testCLI0438virt_clone_auto_unmanaged"
donttest="$donttest or testCLI0442virt_clone"
donttest="$donttest or testCLI0443virt_clone"
donttest="$donttest or testCLI0457virt_clone"
donttest="$donttest or testCLI0458virt_clone"
donttest="$donttest or testCLI0460virt_clone"
donttest="$donttest or testCLI0461virt_clone"
donttest="$donttest or testCLI0468virt_clone"
donttest="$donttest or test_virtinstall_no_testsuite"
donttest="$donttest or testCheckXMLBuilderProps"
donttest="$donttest or testCheckCLISuboptions"
#
pytest -v -rfEs -k "not ($donttest)"
%endif

%post
/bin/touch --no-create %{_datadir}/icons/hicolor >/dev/null 2>&1 || :
/usr/bin/update-desktop-database > /dev/null 2>&1 || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor >/dev/null 2>&1
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor >/dev/null 2>&1 || :
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas > /dev/null 2>&1 || :
fi
/usr/bin/update-desktop-database > /dev/null 2>&1 || :

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor >/dev/null 2>&1 || :
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas > /dev/null 2>&1 || :

%if !%{with test}
%files
%defattr(-,root,root,-)
%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1*

%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/ui
%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virtManager

%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*/
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%if ! %{?is_sles16}
%{_datadir}/applications/YaST2/virt-install.desktop
%endif
%dir %{_datadir}/glib-2.0
%dir %{_datadir}/glib-2.0/schemas
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml
%dir /usr/lib/supportconfig
%dir /usr/lib/supportconfig/plugins
/usr/lib/supportconfig/plugins/virt_manager

%files common -f %{name}.lang
%defattr(-,root,root,-)
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtinst

%files -n virt-install
%defattr(-,root,root,-)
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-xml.1*

%{_bindir}/virt-install
%{_datadir}/bash-completion/completions/virt-install
%{_bindir}/virt-clone
%{_datadir}/bash-completion/completions/virt-clone
%{_bindir}/virt-xml
%{_datadir}/bash-completion/completions/virt-xml

%if ! %{?is_sles16}
%dir %{_datadir}/YaST2
%dir %{_datadir}/YaST2/clients
%dir %{_datadir}/applications/YaST2
%{_datadir}/YaST2/clients/virt-install.rb
%endif
%endif

%changelog
* Mon Apr 14 2025 carnold@suse.com
- Spec file changes for including the correct dependencies
  depending on the distro. (bsc#1241082 and bsc#1241119)
* Fri Apr 11 2025 carnold@suse.com
- Upstream features and bug fixes (bsc#1027942) (jsc#PED-8910)
  040-virtinst-add-pstore-backend-support.patch
  041-tests-add-pstore-test.patch
  042-man-virt-install-Document-pstore-device.patch
  043-tests-Increase-virtio-mem-block-size.patch
  044-tests-test_urls-fix-dead-URL.patch
  045-urlfetcher-add-riscv64-architecture-for-Debian.patch
  046-virt-manager-list-virtual-networks-when-creating-new-QEMU-Session-VM.patch
  047-virt-install-add-support-for-vDPA-network-device.patch
  048-virt-manager-add-support-for-vDPA-network-device.patch
  049-virt-install-detect-wayland-in-order-to-start-virt-viewer.patch
- bsc#1241082 - [Build 20250410] virt_install fails to launch:
  missing dependencies.
  Spec file modifications
* Tue Apr  8 2025 carnold@suse.com
- bsc#1239837 - [SLFO] virt-manager still has unresolved
  dependencies in beta2
  Remove dependencies on spice and other Gtk sources as these
  packages don't exist in SLES16. Cleanup other dependencies.
  virt-manager.spec
* Wed Mar 12 2025 carnold@suse.com
- Upstream bug fix (bsc#1027942)
  010-virtManager-domain-fix-indentation.patch
- Upstream features from Lin Ma and others (jsc#PED-8910)
  021-cli-Add-memdev-target.dynamicMemslots-support-for-virtio-mem.patch
  022-cli-add-target.memReserve-for-pci-bridge-and-pcie-root-port-controllers.patch
  023-cli-Add-disk-driver.queue_size-support.patch
  024-cli-Add-poll-settings-for-iothread.patch
  025-test_cli-Fix-a-pycodestyle-E261-issue.patch
  026-gitignore-Ignore-coverage.xml.patch
  027-cli-Add-tpm-backend.profile.source-removeDisabled-support.patch
  028-cli-Add-nvram.templateFormat-to-indicate-template-format.patch
  029-cli-Add-features-hyperv.xmm_input.state-on-off.patch
  030-cli-Add-features-hyperv.emsr_bitmap.state-on-off.patch
  031-cli-Add-features-hyperv.tlbflush.direct.state-on-off.patch
  032-cli-Add-features-hyperv.tlbflush.extended.state-on-off.patch
  033-createvm-prioritize-riscv64.patch
  034-tests-uitests-handle-linux2020-going-EOL.patch
* Thu Mar  6 2025 carnold@suse.com
- bsc#1239013 - Unable to install an SEV-SNP guest with virt-install
  virtinst-dont-require-uefi-for-sev-snp.patch
* Thu Feb 27 2025 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded Requires on python3-ipaddr.
* Tue Feb 11 2025 carnold@suse.com
- Spec file modifications for SLES16 and some cleanups
  virt-manager.spec
- Add additional detection code for SLES 16 media (bsc#1236252)
  virtinst-add-sle16-detection-support.patch
* Tue Jan 28 2025 carnold@suse.com
- Upstream bug fixes (bsc#1027942) (jsc#PED-8910)
  001-cli-Support-cpu-maximum.patch
  002-gui-Support-maximum-CPU-mode.patch
  003-cpu-Prefer-maximum-mode-for-many-emulated-guests.patch
  004-domcaps-get-list-of-supported-panic-device-models.patch
  005-tests-Update-capabilities-for-advertisting-panic-device-models.patch
  006-addhardware-panic-Fill-in-model-combo-with-advertised-values-by-libvirt.patch
  007-cli-man-Always-list-osinfo-before-os-variant.patch
  008-snapshots-default-to-same-snapshot-mode-as-currently-used-snapshot.patch
  009-snapshots-warn-users-to-not-mix-snapshot-modes.patch
- Drop virtinst-dont-use-special-copy-cpu-features.patch
* Fri Jan 17 2025 carnold@suse.com
- Fix issue being able to detect SLES 16 media (jsc#PED-8910)
  See also bsc#1236252
  virtinst-add-sle16-detection-support.patch
* Thu Dec  5 2024 carnold@suse.com
- bsc#1234215 - fail to install a guest with virt-install and
  report "AttributeError: 'str' object has no attribute 'removeprefix'"
  virtinst-drop-removeprefix-usage.patch
* Tue Nov 26 2024 carnold@suse.com
- Update to Version 5.0.0 (jsc#PED-8910)
  * virt-clone: colne serial files (Oleg Vasilev)
  * virt-clone: Copy disk permissions as well (Martin Kletzander)
  * virt-install: Add properties for AMD SEV-SNP (Daniel P. Berrangé)
  * virt-install: Add passt backend for user network interface
  * virt-install: Add support for --sound multichannel,stream (Lin Ma)
  * virt-install: Add support for --tpm backend.debug,backend.source (Lin Ma)
  * virt-xml: add --edit --convert-to-q35
  * virt-xml: add --edit --convert-to-vnc
  * virt-xml: Add --edit --boot uefi
  * virt-manager: Fix opening graphical console with egl-headless (Feng Jiang)
  * virt-manager: Add support to create external snapshots
  * virt-manager: Default to scaling=Always for consoles
  * virt-manager: switch to not forking by default
  * cli: Add more --disk options (Lin Ma)
  * cli: Add --memdev target.address_base for virtio-mem and virtio-pmem (Lin Ma)
  * cli: Add --features kvm.pv-ipi.state=on|off (Lin Ma)
  * cli: Add --video model.blob=on|off (Lin Ma)
  * Add missing Hyper-V features and enable most of them by default
  * Add loongarch support (Xianglai Li)
  * Add support for hvf domain type (Mohamed Akram)
  * Support creating sparse volumes on ZFS pools (Iain Buclaw)
  * UEFI improvements for riscv64 and loongarch64 VMs (Andrea Bolognani)
  * Add graphcis to riscv64 and aarch64
  * build: swtich from setuptools to meson
  * diskbackend: Drop support for sheepdog (Lin Ma)
  * cli: Deprecate --cpu host in favor of --cpu host-model (Andrea Bolognani)
- Drop the following upstream patches contained in new tarball
  001-cli-disk-Add-driver.metadata_cache-options.patch
  002-tests-cli-Fix-test-output-after-previous-commit.patch
  003-fsdetails-Fix-an-error-with-source.socket-of-virtiofs.patch
  004-cli-Drop-unnecessary-disk-prop-aliases.patch
  005-tests-testdriver-Add-filesystem-socket-example.patch
  006-virtinstall-split-no_install-conditional-apart-to-track-code-coverage.patch
  007-virtinstall-fix-regression-with-boot-and-no-install-method.patch
  008-tests-Add-a-compat-check-for-linux2020-in-amd-sev-test-case.patch
  009-cli-cpu-Add-maxphysaddr.mode-bits-options.patch
  010-virt-install-help-required-options-are-wrong.patch
  011-cloner-Sync-uuid-and-sysinfo-system-uuid.patch
  012-virt-install-unattended-and-cloud-init-conflict.patch
  013-virt-install-Reuse-cli.fail_conflicting.patch
  014-cli-support-boot-loader.stateless-.patch
  015-diskbackend-Drop-support-for-sheepdog.patch
  016-Fix-pylint-pycodestyle-warnings-with-latest-versions.patch
  017-tests-cpio-set-owner-to-00.patch
  018-addhardware-Fix-backtrace-when-controller.index-is-None.patch
  019-Clean-up-FileChooser-usage-a-bit.patch
  020-guest-Query-availability-of-usb-redirdevs-in-domcaps.patch
  021-guest-Query-availability-of-spicevmc-channels-in-domcaps.patch
  022-tests-Add-domcaps-coverage-for-usb-redir-spicevmc-channel-checks.patch
  023-tests-Update-to-latest-kvm-domcaps.patch
  024-progress-Fix-showing-correct-final-total.patch
  025-virtinstall-Fix-the-allocating-disk-size-printed-by-the-progress-bar.patch
  026-virtinstall-Hide-total_size-in-the-progress-bar-if-it-doesnt-need.patch
  027-asyncjob-Fix-backtrace-when-no-cursor-theme-installed.patch
  029-asyncjob-Remove-unused-import.patch
  030-Packit-initial-enablement.patch
  031-virt-install-Recommend-boot-uefi.patch
  032-virt-install-Document-Secure-Boot-setups.patch
  033-cloner-clone-serial-files.patch
  034-tests-cli-test-serial-file-clone.patch
  035-man-virt-install-Add-a-note-about-different-behavior-of-boot-on-s390x.patch
  036-tests-uitests-Fix-window-reposition-on-f38.patch
  037-tests-livetests-work-around-qemu-media-change-regression.patch
  038-tests-uitests-Fix-manager-window-repositioning-test.patch
  039-tests-Default-uitests-to-verbosity-2.patch
  040-uitests-Make-hotplug-test-pass-on-both-f37-and-f38.patch
  041-uitests-More-attempts-at-making-manager-reposition-test-reliable.patch
  042-tests-uitests-make-menu-operations-more-robust.patch
  043-rpm-convert-license-to-SPDX-format.patch
  044-uitests-Drop-hotplug-work-around-f38-libvirt-is-fixed-now.patch
  045-virtinst-delay-lookup_capsinfo-until-we-really-need-it.patch
  046-virtinst-suppress-lookup_capsinfo-exception-in-machine-type-alias-check.patch
  047-tests-data-refresh-Fedora-tree-URLs-in-virt-install-osinfo-expected-XMLs.patch
  048-tests-Add-unit-test-coverage-for-539.patch
  049-fix-indentation-of-multiline-log.exception-invocations.patch
  050-virt-clone-Copy-disk-permissions-as-well.patch
  051-data-appstream-add-launchable-tag.patch
  052-Fix-some-pylint.patch
  055-connectauth-Drop-sanity-checking-for-libvirtd.patch
  056-delete-Fix-ambiguity-that-confused-pylint.patch
  057-Fix-filesystem-socket.source.patch
  058-uri-Mock-domcaps-returning-NO_SUPPORT.patch
  059-tests-cli-Adjust-hotplug-test-for-latest-libvirt.patch
  060-Fix-some-pylint.patch
  061-tests-ui-make-newvm-test-start-less-flakey.patch
  062-tests-ui-make-creatnet-test-start-less-flakey.patch
  063-Support-creating-sparse-volumes-on-ZFS-pools.patch
  064-domain-rename-handle-firmware-ending-with-.qcow2.patch
  065-testdriver-Add-portgroups-example-to-test-many-devices.patch
  066-netlist-Fix-UI-error-when-virtual-network-doesnt-exist.patch
  067-ui-details-fix-Applications-width.patch
  068-ui-details-Increased-scrolledview6s-height-request.patch
  069-uitests-Fix-walkUI-flakyness.patch
  070-uitests-Handle-slow-app-launch-on-fedora-39.patch
  071-createvm-Replace-deprecated-pkgutil.find_loader.patch
  072-Fix-pylint-3.1.0-issues.patch
  073-console-Move-embeddable_graphics-to-console.py.patch
  074-domain-Add-idx-parameter-to-open_graphics_fd.patch
  075-console-Select-the-first-embeddable-graphics-device-as-graphical-console.patch
  076-console-Cleanup-and-improve-console-menu-handling.patch
  077-cli-add-show-systray-option.patch
  078-man-document-show-systray-option.patch
  079-baseclass-Avoid-glib-Source-ID-XX-not-found-at-app-shutdown.patch
  080-uitests-More-handling-for-slow-startup-on-f39.patch
  081-systray-Cleanups-and-improvements-for-show-systray.patch
  082-virtinst-add-external-snapshot-capability.patch
  083-virtinst-snapshot-add-memory-file-attribute.patch
  084-virtManager-domain-allow-disk-only-snapshots.patch
  085-virtManager-add-support-to-create-external-snapshots.patch
  086-virtManager-ignore-agen-livecycle-event-for-shutoff-VMs.patch
  087-Allow-serial-console-resize-to-beyond-80-columns.patch
  088-tests-Fix-host-copy-XML-with-libvirt-10.1.0.patch
  089-hostdev-Fix-error-when-mdev-type_id-is-missing.patch
  090-db1b2fbc-Use-GtkFileChooserNative.patch
  091-uitests-Fix-with-GtkFileChooserNative.patch
  092-cli-Use-regex-for-grep-and-nogrep-args.patch
  093-cli-Fix-with-latest-libvirt.patch
  094-uitests-handle-newer-libvirt-test-driver-UpdateDevice-support.patch
  095-uitests-force-internal-snapshots-in-test_snapshot.py.patch
- Drop the following downstream patches no longer required
  virtinst-dont-create-storage-pool-for-dryrun.patch
  virtinst-add-pvh-support.patch
  virtinst-enable-video-virtio-for-arm.patch
  virtinst-add-hyperv-performance-options.patch
  virtman-dont-specify-gtksource-version.patch
  virtman-language-fixes.patch
* Tue Nov  5 2024 carnold@suse.com
- dbus-1-x11 is being removed from Tumbleweed so drop dependency in
  virt-manager. Add dependency on python3-dbus-python.
* Tue Oct  8 2024 carnold@suse.com
- bsc#1231400 - Virt-manager is missing support for AMD sev-snp
  virtman-add-sev-memory-support.patch
* Tue Sep 17 2024 carnold@suse.com
- Fix SUSE SL Micro detection
  virtinst-add-slem60-detection-support.patch
* Mon Aug 26 2024 carnold@suse.com
- Solve bsc#1228384 --dry-run creating pools in a different way
  virtinst-dont-create-storage-pool-for-dryrun.patch
* Thu Aug 22 2024 carnold@suse.com
- Upstream bug fixes (bsc#1027942) (jsc#PED-8910)
  094-uitests-handle-newer-libvirt-test-driver-UpdateDevice-support.patch
  095-uitests-force-internal-snapshots-in-test_snapshot.py.patch
* Tue Aug  6 2024 carnold@suse.com
- Fix test failure with libvirt version 10.6.0
  092-cli-Use-regex-for-grep-and-nogrep-args.patch
  093-cli-Fix-with-latest-libvirt.patch
* Mon Jul 29 2024 carnold@suse.com
- bsc#1228384 - virt-install generates unwanted libvirt storage
  pools when running with --dry-run --print-xml
  virtinst-dont-create-storage-pool-for-dryrun.patch
* Tue Jul 23 2024 carnold@suse.com
- bsc#1228227 - libvirt missing default hyperv options causes
  windows guest performance degredation.
  virtinst-add-hyperv-performance-options.patch
* Sat Jun 29 2024 carnold@suse.com
- bsc#1227116 - osinfo still uses deprecated SL-Micro name
  virtinst-add-slem60-detection-support.patch
  Dropped virtinst-add-slm-detection-support.patch
* Thu Jun 20 2024 Markéta Machová <mmachova@suse.com>
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Tue Jun 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Skip some tests that fail under Pytest 8.x.
* Tue Jun 11 2024 carnold@suse.com
- bsc#1226173 - virt-manager: Browse local does not work anymore
  090-db1b2fbc-Use-GtkFileChooserNative.patch
  Renamed 090-uitests-Fix-with-GtkFileChooserNative.patch to
  091-uitests-Fix-with-GtkFileChooserNative.patch
* Thu May 23 2024 carnold@suse.com
- Upstream bug fixes (bsc#1027942) (jsc#PED-6305)
  088-tests-Fix-host-copy-XML-with-libvirt-10.1.0.patch
  089-hostdev-Fix-error-when-mdev-type_id-is-missing.patch
  090-uitests-Fix-with-GtkFileChooserNative.patch
* Thu May 16 2024 carnold@suse.com
- Upstream bug fixes (bsc#1027942) (jsc#PED-6305)
  063-Support-creating-sparse-volumes-on-ZFS-pools.patch
  064-domain-rename-handle-firmware-ending-with-.qcow2.patch
  065-testdriver-Add-portgroups-example-to-test-many-devices.patch
  066-netlist-Fix-UI-error-when-virtual-network-doesnt-exist.patch
  067-ui-details-fix-Applications-width.patch
  068-ui-details-Increased-scrolledview6s-height-request.patch
  069-uitests-Fix-walkUI-flakyness.patch
  070-uitests-Handle-slow-app-launch-on-fedora-39.patch
  071-createvm-Replace-deprecated-pkgutil.find_loader.patch
  072-Fix-pylint-3.1.0-issues.patch
  073-console-Move-embeddable_graphics-to-console.py.patch
  074-domain-Add-idx-parameter-to-open_graphics_fd.patch
  075-console-Select-the-first-embeddable-graphics-device-as-graphical-console.patch
  076-console-Cleanup-and-improve-console-menu-handling.patch
  077-cli-add-show-systray-option.patch
  078-man-document-show-systray-option.patch
  079-baseclass-Avoid-glib-Source-ID-XX-not-found-at-app-shutdown.patch
  080-uitests-More-handling-for-slow-startup-on-f39.patch
  081-systray-Cleanups-and-improvements-for-show-systray.patch
  082-virtinst-add-external-snapshot-capability.patch
  083-virtinst-snapshot-add-memory-file-attribute.patch
  084-virtManager-domain-allow-disk-only-snapshots.patch
  085-virtManager-add-support-to-create-external-snapshots.patch
  086-virtManager-ignore-agen-livecycle-event-for-shutoff-VMs.patch
  087-Allow-serial-console-resize-to-beyond-80-columns.patch
- Modifications to the Categories in virt-install.desktop and
  virtman-desktop.patch
* Thu May  9 2024 carnold@suse.com
- Enable mdev tests with the introduction of libvirt 10.3.0
  virt-manager.spec
* Tue May  7 2024 carnold@suse.com
- bsc#1222738 - virt-manager shows SLE Micro 6.0 in suggested OS
  version should be SL Micro 6.0
  virtinst-add-slm-detection-support.patch
* Thu Mar  7 2024 carnold@suse.com
- Disable mdev tests with introduction of libvirt 10.1.0
  virt-manager.spec
* Mon Feb 12 2024 carnold@suse.com
- bsc#1219791 - [virt-manager][aarch64] Error launching details:
  name 'log' is not defined
  virtinst-enable-video-virtio-for-arm.patch
* Fri Feb  9 2024 carnold@suse.com
- Handle case where vm-install no longer exists on the host. This
  is related to bsc#1219133.
  virt-install.rb
* Wed Jan 24 2024 carnold@suse.com
- Upstream bug fixes (bsc#1027942) (jsc#PED-6305)
  058-uri-Mock-domcaps-returning-NO_SUPPORT.patch
  059-tests-cli-Adjust-hotplug-test-for-latest-libvirt.patch
  060-Fix-some-pylint.patch
  061-tests-ui-make-newvm-test-start-less-flakey.patch
  062-tests-ui-make-creatnet-test-start-less-flakey.patch
- Cleanup now working or non-existant %%check tests
* Fri Jan 19 2024 carnold@suse.com
- bsc#1218983 - [SLE15SP6] virt-manager:test testCLI0264virt_xml
  fails with libvirt 10.0.0. Disable this test for now.
  virt-manager.spec
* Mon Nov 20 2023 carnold@suse.com
- Upstream bug fixes (bsc#1027942) (jsc#PED-6305)
  001-cli-disk-Add-driver.metadata_cache-options.patch
  002-tests-cli-Fix-test-output-after-previous-commit.patch
  003-fsdetails-Fix-an-error-with-source.socket-of-virtiofs.patch
  004-cli-Drop-unnecessary-disk-prop-aliases.patch
  005-tests-testdriver-Add-filesystem-socket-example.patch
  006-virtinstall-split-no_install-conditional-apart-to-track-code-coverage.patch
  007-virtinstall-fix-regression-with-boot-and-no-install-method.patch
  008-tests-Add-a-compat-check-for-linux2020-in-amd-sev-test-case.patch
  009-cli-cpu-Add-maxphysaddr.mode-bits-options.patch
  010-virt-install-help-required-options-are-wrong.patch
  011-cloner-Sync-uuid-and-sysinfo-system-uuid.patch
  012-virt-install-unattended-and-cloud-init-conflict.patch
  013-virt-install-Reuse-cli.fail_conflicting.patch
  014-cli-support-boot-loader.stateless-.patch
  015-diskbackend-Drop-support-for-sheepdog.patch
  016-Fix-pylint-pycodestyle-warnings-with-latest-versions.patch
  017-tests-cpio-set-owner-to-00.patch
  018-addhardware-Fix-backtrace-when-controller.index-is-None.patch
  019-Clean-up-FileChooser-usage-a-bit.patch
  020-guest-Query-availability-of-usb-redirdevs-in-domcaps.patch
  021-guest-Query-availability-of-spicevmc-channels-in-domcaps.patch
  022-tests-Add-domcaps-coverage-for-usb-redir-spicevmc-channel-checks.patch
  023-tests-Update-to-latest-kvm-domcaps.patch
  024-progress-Fix-showing-correct-final-total.patch
  025-virtinstall-Fix-the-allocating-disk-size-printed-by-the-progress-bar.patch
  026-virtinstall-Hide-total_size-in-the-progress-bar-if-it-doesnt-need.patch
  027-asyncjob-Fix-backtrace-when-no-cursor-theme-installed.patch
  029-asyncjob-Remove-unused-import.patch
  030-Packit-initial-enablement.patch
  031-virt-install-Recommend-boot-uefi.patch
  032-virt-install-Document-Secure-Boot-setups.patch
  033-cloner-clone-serial-files.patch
  034-tests-cli-test-serial-file-clone.patch
  035-man-virt-install-Add-a-note-about-different-behavior-of-boot-on-s390x.patch
  036-tests-uitests-Fix-window-reposition-on-f38.patch
  037-tests-livetests-work-around-qemu-media-change-regression.patch
  038-tests-uitests-Fix-manager-window-repositioning-test.patch
  039-tests-Default-uitests-to-verbosity-2.patch
  040-uitests-Make-hotplug-test-pass-on-both-f37-and-f38.patch
  041-uitests-More-attempts-at-making-manager-reposition-test-reliable.patch
  042-tests-uitests-make-menu-operations-more-robust.patch
  043-rpm-convert-license-to-SPDX-format.patch
  044-uitests-Drop-hotplug-work-around-f38-libvirt-is-fixed-now.patch
  045-virtinst-delay-lookup_capsinfo-until-we-really-need-it.patch
  046-virtinst-suppress-lookup_capsinfo-exception-in-machine-type-alias-check.patch
  047-tests-data-refresh-Fedora-tree-URLs-in-virt-install-osinfo-expected-XMLs.patch
  048-tests-Add-unit-test-coverage-for-539.patch
  049-fix-indentation-of-multiline-log.exception-invocations.patch
  050-virt-clone-Copy-disk-permissions-as-well.patch
  051-data-appstream-add-launchable-tag.patch
  052-Fix-some-pylint.patch
  055-connectauth-Drop-sanity-checking-for-libvirtd.patch
  056-delete-Fix-ambiguity-that-confused-pylint.patch
  057-Fix-filesystem-socket.source.patch
- Replaced patches
  11a887ec-cli-disk-Add-driver.metadata_cache-options.patch
  1cb0be40-virtinstall-split-no_install-conditional-apart-to-track-code-coverage.patch
  58f5e36d-fsdetails-Fix-an-error-with-source.socket-of-virtiofs.patch
  67832d30-addhardware-Fix-backtrace-when-controller-index-is-None.patch
  7295ebfb-tests-cli-Fix-test-output-after-previous-commit.patch
  999ccb85-virt-install-unattended-and-cloud-init-conflict.patch
  b0d05167-cloner-Sync-uuid-and-sysinfo-system-uuid.patch
  c22a876e-tests-Add-a-compat-check-for-linux2020-in-amd-sev-test-case.patch
  e94786c0-virtinstall-fix-regression-with-boot-and-no-install-method.patch
  fbdf0516-cli-cpu-Add-maxphysaddr.mode-bits-options.patch
- Dropped patches
  virtman-check-for-libvirt-modular-daemons.patch
  virtman-fix-osinfo-tests.patch
* Wed Oct 18 2023 jfehlig@suse.com
- Supportconfig: Adapt plugin to modern supportconfig
  The supportconfig 'scplugin.rc' file is deprecated in favor of
  supportconfig.rc'. Adapt the virt-manager plugin to the new scheme.
  virt-manager-supportconfig
* Mon Jul 31 2023 carnold@suse.com
- bsc#1213790 - Application tab in virt-manager is collapsed,
  therefore I can't read anything
  virtman-fix-inspection-apps-window.patch
* Tue Jun 13 2023 carnold@suse.com
- bsc#1212195 - libvirtd crashes when virt-manager connects
  virt-manager qemu:///system on a fresh installation tumbleweed
  virtman-check-for-libvirt-modular-daemons.patch
- Changes to osinfo-db cause some virt-manager tests to fail.
  virtman-fix-osinfo-tests.patch
* Tue Apr 25 2023 carnold@suse.com
- bsc#1201748 - virt-install --graphics vnc fails with not support
  for video model 'virtio'
  virtinst-enable-video-virtio-for-arm.patch
* Mon Apr 17 2023 carnold@suse.com
- Drop virtman-check-for-valid-display.patch. This patch is no
  longer required.
* Thu Apr  6 2023 carnold@suse.com
- Language file fixes
  bsc#1209800, bsc#1197945, bsc#1197947, bsc#1198041
  virtman-language-fixes.patch
* Fri Jan 20 2023 carnold@suse.com
- bsc#1207070 - libvirt fails to start the guest once the new
  shared disk is added, with the error, "cannot get 'write'
  permission without 'resize' image size is not a multiple of
  request alignment"
  virtman-fix-shared-disk-request-alignment-error.patch
* Thu Jan  5 2023 carnold@suse.com
- Replace downstream patch with upstream version (bsc#1203252)
  67832d30-addhardware-Fix-backtrace-when-controller-index-is-None.patch
  Drop virtman-fix-uninitialized-controller-index.patch
* Mon Nov 28 2022 carnold@suse.com
- bsc#1205675 - [Build 20221122] virt-install: Specifying --boot no
  longer implies no_install=yes
  1cb0be40-virtinstall-split-no_install-conditional-apart-to-track-code-coverage.patch
  e94786c0-virtinstall-fix-regression-with-boot-and-no-install-method.patch
* Tue Nov 15 2022 carnold@suse.com
- bsc#1203252 - virt-manager regression - cannot add second
  virtio-scsi controller
  virtman-fix-uninitialized-controller-index.patch
* Mon Nov  7 2022 carnold@suse.com
- Refresh test skips
- Drop the very old "Obsoletes: python-virtinst <= 0.600.4"
  virt-manager.spec
* Fri Nov  4 2022 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  11a887ec-cli-disk-Add-driver.metadata_cache-options.patch
  7295ebfb-tests-cli-Fix-test-output-after-previous-commit.patch
  58f5e36d-fsdetails-Fix-an-error-with-source.socket-of-virtiofs.patch
  c22a876e-tests-Add-a-compat-check-for-linux2020-in-amd-sev-test-case.patch
  fbdf0516-cli-cpu-Add-maxphysaddr.mode-bits-options.patch
  b0d05167-cloner-Sync-uuid-and-sysinfo-system-uuid.patch
  999ccb85-virt-install-unattended-and-cloud-init-conflict.patch
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Fri Aug  5 2022 Ben Greiner <code@bnavigator.de>
- Update to 4.1.0
  * Fix build with setuptools-61 (Peter Alfredsen, Miro Hrončok)
  * add UI and cli support for qemu-vdagent channel (Jonathon Jongsma)
  * cli: More --iothreads suboptions (Lin Ma)
  * launch_security: Use SEV-ES policy=0x07 if host supports it (Charles
  * Arnold)
  * cli: Add support for URL query with disks (Martin Kletzander)
- Drop patches merged upstream:
  * c6107419-tests-Drop-usage-of-sgio-unfiltered.patch
  * 90e13549-Fix-build-with-setuptools-61+.patch
  * 46dc0616-setup-add-bits-for-setuptools-61.patch
  * 9ac94ef7-tests-Fix-another-sgio-filtered-case.patch
  * 34662fec-tests-Fix-with-latest-argcomplete.patch
  * d51541e1-Fix-UI-rename-with-firmware-efi.patch
  * b8a77805-domain-cpu-Clear-migratable-when-changing-to-custom-cpu.patch
  * 0d84bcfb-cli-Add-iothreadids-attributes-thread_pool_min-and-thread_pool_max.patch
  * 424283ad-launch_security-Use-SEV-ES-policy-0x07-if-host-supports-it.patch
- Refresh patches
  * virtman-add-tooltip-to-firmware.patch
  - - changed surrounding imports
  * virtinst-set-cache-mode-unsafe-for-install.patch
  - - the patch changes the expected output in tests
- Refresh test skips
* Wed Aug  3 2022 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  c6107419-tests-Drop-usage-of-sgio-unfiltered.patch
  9ac94ef7-tests-Fix-another-sgio-filtered-case.patch
  b8a77805-domain-cpu-Clear-migratable-when-changing-to-custom-cpu.patch
  0d84bcfb-cli-Add-iothreadids-attributes-thread_pool_min-and-thread_pool_max.patch
  90e13549-Fix-build-with-setuptools-61+.patch
  424283ad-launch_security-Use-SEV-ES-policy-0x07-if-host-supports-it.patch
- Modified virtman-add-sev-memory-support.patch
- Renamed upstream patches
  virtman-pr381-setuptools-61.patch to
    46dc0616-setup-add-bits-for-setuptools-61.patch
  virtman-34662fe-argcomplete.patch to
    34662fec-tests-Fix-with-latest-argcomplete.patch
* Tue Jul 19 2022 Ben Greiner <code@bnavigator.de>
- Add Source URL
- Add upstream patch virtman-pr381-setuptools-61.patch
  gh#virt-manager/virt-manager#381
- Enable tests
  * No python package should go untested
  * Use multibuild so that all runtime requirements are checked
  * Add virtman-34662fe-argcomplete.patch
* Tue Jul 12 2022 carnold@suse.com
- Upstream bug fix (bsc#1027942)
  d51541e1-Fix-UI-rename-with-firmware-efi.patch
- Use autosetup in spec file
* Wed Jun 22 2022 carnold@suse.com
- bsc#1200691 - SLES 15 SP4 GMC --os-variant tag shouldn't be
  mandatory on s390x (see also bsc#1200422)
  revert-363fca41-virt-install-Require-osinfo-for-non-x86-HVM-case-too.patch
* Mon May 23 2022 carnold@suse.com
- Change dependency on package xorriso to Requires from Recommends
  virt-manager.spec
* Wed Mar 30 2022 carnold@suse.com
- bsc#1196806 - [jsc#SLE-18834][virt-install] ERROR SEV launch
  security requires a Q35 UEFI machine (epic: jsc#SLE-18732)
  virtman-add-sev-memory-support.patch
- Add firmware features to description tooltip when mouse hovers
  over the selected firmware file.
  virtman-add-tooltip-to-firmware.patch
* Wed Mar  2 2022 carnold@suse.com
- bsc#1196202 - virt-install crashes on a time-of-check time-of-use
  (TOCTOU) race condition
  Resolved by upgrade to version 4.0.0 (jsc#SLE-18261)
  virt-manager-4.0.0.tar.gz
- Other features and bug fixes (bsc#1027942)
  virt-install –os-variant/–osinfo is now a hard requirement for most cases
  Add ‘Enable shared memory’ UI checkbox (Lin Ma)
  add UI preference to default to UEFI for new VMs (Charles Arnold)
  Add virtiofs filesystem driver UI option
  Fill in all –cputune, –cpu, –shmem, –input, and –boot suboptions (Hugues Fafard)
  virt-* mdev improvements (Shalini Chellathurai Saroja)
  bhyve improvments (Roman Bogorodskiy)
  Revive network portgroup UI
  enable a TPM by default when UEFI is used (Daniel P. Berrangé)
  Use cpu host-passthrough by default on qemu x86
  use virtio-gpu video for most modern distros
  Default to extra pcie root ports for q35
  set discard=unmap by default for sparse disks and block devices
  We now require xorissofs for –location ISO
  We now use setuptools rather than just plain distutils
- Add virtman-revert-use-of-AyatanaAppIndicator3.patch
- Drop the following patches
  0e15cd51-virt-manager-enable-MDEV-support.patch
  143c6bef-virtinst-fix-error-message-format-string.patch
  4d0e3232-virtinst-Fix-TOCTOU-in-domain-enumeration.patch
  8bb64ad5-console-Dont-block-console-reconnect-for-non-error.patch
  9363e1e6-virt-xml-add-support-for-mediated-devices.patch
  965480e8-virt-install-add-mediated-device.patch
  9d4002ee-tests-verify-MDEV-support.patch
  cf93e2db-console-fix-error-with-old-pygobject.patch
  d3c627f1-volumeupload-Use-1MiB-read-size.patch
  d9b5090e-Fix-forgetting-password-from-keyring.patch
  e7222b50-addstorage-Dont-pass-None-to-widget.set_active.patch
  f87e96d3-hostdev-use-method-get_mdev_uuid.patch
  fe8722e7-createnet-Remove-some-unnecessary-max_length-annotations.patch
  virtinst-graphics-add-check-for-qemu-modules-in-spice-graphic.patch
  virtman-add-firmware-preferences.patch
  virtman-legacy-bios-support.patch
  virtman-show-no-firmware-for-xenpv.patch
* Thu Jan 20 2022 carnold@suse.com
- bsc#1194323 - [jsc#SLE-19237][virt-manager] Detected the wrong
  win2k22 guest system version from the local install media
  virtinst-windows-server-detection.patch
- Upstream bug fixes (bsc#1027942)
  8bb64ad5-console-Dont-block-console-reconnect-for-non-error.patch
  Drop virtman-init-viewer-on-reboot.patch
* Thu Jan 13 2022 carnold@suse.com
- jsc#SLE-20855 KVM: Enable vfio-ccw and vfio-ap in virt-* tools
  965480e8-virt-install-add-mediated-device.patch
  f87e96d3-hostdev-use-method-get_mdev_uuid.patch
  9d4002ee-tests-verify-MDEV-support.patch
  9363e1e6-virt-xml-add-support-for-mediated-devices.patch
  0e15cd51-virt-manager-enable-MDEV-support.patch
* Tue Nov 23 2021 carnold@suse.com
- jsc#SLE-17735 - Support Oracle Linux as a guest VM. See also
  bsc#1192238 [Build58.2][KVM] The latest supported OracleLinux as
  guest versions are not included anywhere
  virtinst-add-oracle-linux-support.patch
* Thu Oct 28 2021 carnold@suse.com
- bsc#1188223 - L3: Sles12sp3 DomU won't boot after adding phys
  hard drive
  virtinst-xenbus-disk-index-fix.patch
* Tue Oct 26 2021 carnold@suse.com
- jsc#SLE-21540 Dev: Prefer UEFI when creating new virtual machines.
  Add a preferences option to allow users to default to UEFI when
  creating a new VM. Libvirt decides which firmware file to use.
  virtman-add-firmware-preferences.patch
- Renamed patch virtinst-modify-gui-defaults.patch to
  virtman-modify-gui-defaults.patch
* Fri Oct 22 2021 carnold@suse.com
- Add dependency in spec file for python3-gobject-Gdk (bsc#1191705)
  virt-manager.spec
* Tue Oct 12 2021 carnold@suse.com
- bsc#1191358 - The Virtual Machine Manager shows disconnected
  after rebooting virtual machine in Xen mode in SLES15 SP3.
  virtman-init-viewer-on-reboot.patch
* Thu Oct  7 2021 carnold@suse.com
- bsc#1191356 - virt-manager should not depend on gtk4
  Modified files:
    virt-manager.spec
    virtman-dont-specify-gtksource-version.patch
    virtman-dont-specify-vte-version.patch
* Mon Oct  4 2021 carnold@suse.com
- jsc#SLE-20856 Dev: KVM: Enable vfio-ccw and vfio-ap in virt-* tools
  965480e8-virt-install-add-mediated-device.patch
* Wed Sep  8 2021 carnold@suse.com
- bsc#1190215 - [virt-install] No Support for SUSE Product SLE-HPC
  virtinst-add-sle-hpc-support.patch
* Mon Jun 21 2021 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  d3c627f1-volumeupload-Use-1MiB-read-size.patch
  cf93e2db-console-fix-error-with-old-pygobject.patch
  143c6bef-virtinst-fix-error-message-format-string.patch
  fe8722e7-createnet-Remove-some-unnecessary-max_length-annotations.patch
  d9b5090e-Fix-forgetting-password-from-keyring.patch
* Mon Apr 12 2021 carnold@suse.com
- Add support for detecting SUSE Linux Enterprise Micro. See also
  the osinfo-db package for the SLEM OS description file.
  virtinst-add-slem-detection-support.patch
* Wed Feb 24 2021 acho@suse.com
- bsc#1178926 - Unable to find any master var for loader
  /usr/share/qemu/{bios.bin, bios-256k.bin}
  virtman-legacy-bios-support.patch
* Mon Jan 25 2021 carnold@suse.com
- bsc#1180897 - SLES15 SP2: VM does not boot after virt-install
  installing from ISO image.
  virtinst-keep-iso-for-xenpv.patch
* Mon Jan 25 2021 carnold@suse.com
- bsc#1181350 - [Build 20210122] openQA test fails in virt_install
  on aarch64
  virtman-show-no-firmware-for-xenpv.patch
* Thu Jan  7 2021 carnold@suse.com
- bsc#1180069 - L3: virsh edit Error: XML document failed to
  validate against schema: Unable to validate doc.
  virtinst-smbios-unsupported-for-xenpv.patch
* Tue Jan  5 2021 carnold@suse.com
- bsc#1180047 - [xen][virt-manger] Libvirt or Hyperisor does not
  support UEFI for 15SP3 XENPV Guest
  virtman-show-no-firmware-for-xenpv.patch
* Fri Dec 18 2020 carnold@suse.com
- bsc#1180062 - virt-install uses isoinfo. Include mkisofs in the
  spec file.
  virt-manager.spec
* Wed Dec  9 2020 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  e7222b50-addstorage-Dont-pass-None-to-widget.set_active.patch
  4d0e3232-virtinst-Fix-TOCTOU-in-domain-enumeration.patch
* Mon Nov 30 2020 carnold@suse.com
- bsc#1179236 - L3: virt-install: "Error validating install
  location: invalid literal for int() with base 10" reported by
  virt-install ref:_00D1igLOd._5001iTe00n:ref
  virtinst-sap-detection.patch
* Wed Nov 25 2020 Bruce Rogers <brogers@suse.com>
- boo#1178141 - Accomodate qemu modularization with respect to v5.2
  qemu changes, where 3 additional modular shared objects need to
  be present for spice support. This change simply augments what
  was done before, adding the additional code to the same patch
* Fri Nov 20 2020 carnold@suse.com
- bsc#1172340 - Several YaST modules can be started by typing
  "yast2 $module <tab><tab>"
  virt-install.rb
* Mon Nov 16 2020 carnold@suse.com
- jsc#SLE-16582, Upgrade virt-manager >= 3.x
  * Slim down filesystem device editor UI
  * Fix TOCTTOU virt-install bugs (Martin Pitt)
  * Several other bug fixes
  virt-manager-3.2.0.tar.bz2
- Drop patches contained in new tarball
  1a1e4580-cloner-Explicitly-reject-network-disks-we-dont-know-how-to-clone.patch
  2773bc35-storagepool-cleanup-volumes-on-pool-cleanup.patch
  b1328202-devices-disk-Skip-check_path_search-for-path.patch
  virtman-append-usr-sbin-to-search-path.patch
* Wed Nov 11 2020 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  1a1e4580-cloner-Explicitly-reject-network-disks-we-dont-know-how-to-clone.patch
  2773bc35-storagepool-cleanup-volumes-on-pool-cleanup.patch
  b1328202-devices-disk-Skip-check_path_search-for-path.patch
* Fri Oct 30 2020 carnold@suse.com
- jsc#SLE-12902 virt-manager: Display information about nvram file
  used instead of the path to the Nvram
  virtman-add-tooltip-to-firmware.patch
* Tue Oct 27 2020 carnold@suse.com
- bsc#1177620 - [xen] deployed WIN2K19 guest system could not find
  a driver for network adapter
  virtinst-set-default-nic.patch
* Sat Oct 24 2020 Bruce Rogers <brogers@suse.com>
- boo#1178141 - Accomodate qemu modularization with respect to
  spice and spice related optional modules. If full spice support
  is not detected due to missing qemu modules (v5.1 qemu and newer),
  use vnc as the default install-time graphics type used
  virtinst-graphics-add-check-for-qemu-modules-in-spice-graphic.patch
* Fri Oct 23 2020 carnold@suse.com
- bsc#1177763 - Cannot install an existing virtual machine two
  error messages with Virtual Machine Manager
  virtman-append-usr-sbin-to-search-path.patch
* Wed Sep 30 2020 carnold@suse.com
- jsc#SLE-16582, Upgrade virt-manager >= 3.x
  * Return to using qcow2 sparse by default with libvirt 5.0.0+
  * Make VM window shortcuts less likely to conflict with guest
    usage
  * Fix 3.0.0 regression with spice audio
  * createvol: Add explicit option for qcow2 non-sparse
  * Unconditionally add USB redirdev to new VMs when using SPICE
  * Unconditionally add sound devices to new VMs
  * Translation string improvements (Pino Toscano)
- bsc#1176881 - No audio in virt-manager after upgrade
  virt-manager-3.1.0.tar.bz2
- Drop patches contained in new tarball
  ba08f84b-addstorage-Return-to-using-qcow2-sparse-by-default.patch
  a010c49b-cli-Fix-os-variant-help-introspection.patch
  79ebcbcb-viewers-Fix-spice-audio.patch
  e5a51f63-details-Change-Close-accelerator-to-ctrl+shift+w.patch
  9c13d2f8-Remove-use-of-problematic-terminology.patch
* Mon Sep 28 2020 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  ba08f84b-addstorage-Return-to-using-qcow2-sparse-by-default.patch
  a010c49b-cli-Fix-os-variant-help-introspection.patch
  79ebcbcb-viewers-Fix-spice-audio.patch
  e5a51f63-details-Change-Close-accelerator-to-ctrl+shift+w.patch
  9c13d2f8-Remove-use-of-problematic-terminology.patch
* Wed Sep 16 2020 carnold@suse.com
- jsc#SLE-16582, Upgrade virt-manager >= 3.x
  virt-manager-3.0.0.tar.bz2
  * virt-install –cloud-init support (Athina Plaskasoviti, Cole
    Robinson)
  * The virt-convert tool has been removed. Please use virt-v2v
    instead
  * A handful of UI XML configuration options have been removed.
    The XML editor can be used instead. For a larger discussion see
    this thread: https://www.redhat.com/archives/virt-tools-list/
    2019-June/msg00117.html
  * The ‘New VM’ UI now has a ‘Manual Install’ option which creates
    a VM without any required install media
  * In the ‘New VM’ UI, the network/pxe install option has been
    removed. If you need network boot, choose ‘Manual Install’ and
    set the boot device after initial VM creation
  * ‘Clone VM’ UI has been reworked and simplified
  * ‘Migrate VM’ UI now has an XML editor for the destination VM
  * Global and per-vm option to disable graphical console
    autoconnect. This makes it easier to use virt-manager alongside
    another client like virt-viewer
  * virt-manager: set guest time after VM restore (Michael Weiser)
  * virt-manager: option to delete storage when removing disk
    device (Lily Nie)
  * virt-manager: show warnings if snapshot operation is unsafe
    (Michael Weiser)
  * Unattended install improvements (Fabiano Fidêncio)
  * cli: new –xml XPATH=VAL option for making direct XML changes
  * virt-install: new –reinstall=DOMAIN option
  * virt-install: new –autoconsole text|graphical|none option
  * virt-install: new –os-variant detect=on,require=on suboptions
  * cli: –clock, –keywrap, –blkiotune, –cputune additions (Athina
    Plaskasoviti)
  * cli: add –features kvm.hint-dedicated.state= (Menno Lageman)
  * cli:–iommu option (Menno Lageman)
  * cli: Add –graphics websocket= support (Petr Benes)
  * cli: Add –disk type=nvme source.* suboptions
  * cli: Fill in all –filesystem suboptions
  * Translation string improvements (Pino Toscano)
  * Convert from .pod to .rst for man pages
  * Switch to pytest as our test runner
  * Massively improved unittest and uitest code coverage
  * Now using github issues as our bug tracker
- Drop patches contained in new tarball
  3c6e8537-guest-fix-warning-message-when-machine-type-is-changed-for-secure-boot.patch
  0c223ab2-guest-Dont-set-default-uefi-if-firmware-is-set.patch
  414ffa5e-virt-install-Use-minutes-instead-of-seconds-on-get_time_string.patch
  53245827-urlfetcher-Force-a-flush-after-writing-to-a-file.patch
  3009888a-urlfetcher-Dont-override-fullurl-when-its-explicitly-set.patch
  9465da41-urlfetcher-Deal-with-file-in-_LocalURLFetcher.patch
  651e5b6d-devices-video-Simplify-model-hvm-check.patch
  1547e16d-domcapabilities-Get-video-devices.patch
  2e20b128-domcapabilities-Add-supports_video_bochs.patch
  d9736db9-addhardware-Add-bochs-display-to-the-video-list.patch
  8f4c53ea-video-Prefer-bochs-when-its-supported..patch
  ae19d6d6-fix-resizing-of-spice-clients-with-guest-resizing-enabled.patch
  51d84c54-connection-Avoid-repeated-default-pool-creation-attempts.patch
  d934d6f2-domcaps-Fix-check-for-uncached-security-features.patch
  29f9f5f2-virt-xml-fix-defined_xml_is_unchanged.patch
  15a9502b-Fix-showing-the-firmware-type-in-case-of-firmware-auto-selection.patch
  5573aeb4-createnet-Fix-XML-editor-error-when-dhcp-fields-are-empty.patch
  e8bf16b9-details-fix-detection-of-firmware-auto-selection.patch
  7e3fb3f2-graphics-Default-to-vga-instead-of-qxl-for-non-spice.patch
- Drop deprecated patches
  virtman-fix-env-script-interpreter.patch
  virtinst-osdict-get_supported.patch
  virtconv-python2-to-python3-conversion.patch
  virtinst-python2-to-python3-conversion.patch
  virtman-python2-to-python3-conversion.patch
  virttests-python2-to-python3-conversion.patch
  0002-virtinst-python3-avoid-comparison-of-None-and-int.patch
* Thu Sep  3 2020 carnold@suse.com
- bsc#1176080 - selecting one UEFI firmware in install wizard
  resets UI to BIOS
  e8bf16b9-details-fix-detection-of-firmware-auto-selection.patch
- Upstream bug fix (bsc#1027942)
  5573aeb4-createnet-Fix-XML-editor-error-when-dhcp-fields-are-empty.patch
  7e3fb3f2-graphics-Default-to-vga-instead-of-qxl-for-non-spice.patch
* Wed Sep  2 2020 carnold@suse.com
- jsc#SLE-11773, Dev: virt-manager: AppIndicator3
  virt-manager.spec
- jsc#SLE-15926 - Dev: XEN: drop netware support
  Drop virtman-keycombo.patch
* Wed Jul 29 2020 carnold@suse.com
- bsc#1174176 - IDE: "Only 2 disks for bus 'NONE' are supported"
  virtman-disallow-adding-floppy-disk.patch
* Thu Jul 23 2020 carnold@suse.com
- bsc#1172356 - Not able to hot-plug NIC via virt-manager, asks to
  attach on next reboot while it should be live attached
  virtinst-set-default-nic.patch
* Mon Jul 13 2020 carnold@suse.com
- bsc#1169708 - Virtualization/virt-manager: Bug yast2 virt-install
  internal error
  virt-install.rb
* Tue Mar 24 2020 carnold@suse.com
- bsc#1167569 - SLES 15 SP2 RC1 - virt-install: cache=none is
  ignored (kvm)
  virtinst-set-cache-mode-unsafe-for-install.patch
* Fri Mar 20 2020 carnold@suse.com
- bsc#1167202 - SLES 15 SP2 Snapshot8 - virt-install misses module
  gi
  virt-manager.spec
* Mon Mar  9 2020 carnold@suse.com
- Upstream bug fix (bsc#1027942)
  15a9502b-Fix-showing-the-firmware-type-in-case-of-firmware-auto-selection.patch
* Mon Dec  2 2019 carnold@suse.com
- bsc#1157144 - [s390][virt-manager] There was the black screen
  from guest graphical console during guest installation
  virtinst-s390x-disable-graphics.patch
- bsc#1158227 - virt-manager: Fix duplicate entries in the
  operating system URL drop down menu
  virtman-show-suse-install-repos.patch
- Upstream bug fix (bsc#1027942)
  29f9f5f2-virt-xml-fix-defined_xml_is_unchanged.patch
- Drop virtman-default-to-xen-pv.patch
- Refreshed
  virtinst-add-pvh-support.patch
  virtinst-modify-gui-defaults.patch
  virt-manager.changes
  virt-manager.spec
  virtman-allow-creating-i686-vm.patch
  virtman-python2-to-python3-conversion.patch
* Wed Nov 27 2019 carnold@suse.com
- bsc#1156964 - import a exist disk for creating PV guest failed
  virtinst-pvgrub2-bootloader.patch
- Refreshed patches
  virtinst-change-location-for-grub_xen.patch
  virtinst-set-cache-mode-unsafe-for-install.patch
* Fri Nov 22 2019 carnold@suse.com
- bsc#1157097 - PV guest on_reboot event be set to 'destroy' by
  default
  virtinst-pvgrub2-bootloader.patch
- Rebased patches
  virtinst-change-location-for-grub_xen.patch
  virtman-increase-setKeepAlive-count.patch
* Tue Nov 12 2019 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  1547e16d-domcapabilities-Get-video-devices.patch
  2e20b128-domcapabilities-Add-supports_video_bochs.patch
  ae19d6d6-fix-resizing-of-spice-clients-with-guest-resizing-enabled.patch
  51d84c54-connection-Avoid-repeated-default-pool-creation-attempts.patch
  d934d6f2-domcaps-Fix-check-for-uncached-security-features.patch
* Mon Oct 28 2019 carnold@suse.com
- bsc#1155197 - [xen][virt-manager] Fail to boot up installed
  sles15sp2 PV guest
  virtinst-pvgrub2-bootloader.patch
  virtinst-change-location-for-grub_xen.patch
- Upstream bug fixes (bsc#1027942)
  9465da41-urlfetcher-Deal-with-file-in-_LocalURLFetcher.patch
  651e5b6d-devices-video-Simplify-model-hvm-check.patch
  d9736db9-addhardware-Add-bochs-display-to-the-video-list.patch
  8f4c53ea-video-Prefer-bochs-when-its-supported..patch
* Tue Aug 27 2019 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  0c223ab2-guest-Dont-set-default-uefi-if-firmware-is-set.patch
  414ffa5e-virt-install-Use-minutes-instead-of-seconds-on-get_time_string.patch
  53245827-urlfetcher-Force-a-flush-after-writing-to-a-file.patch
  3009888a-urlfetcher-Dont-override-fullurl-when-its-explicitly-set.patch
* Mon Jul 29 2019 carnold@suse.com
- bsc#1143315 - virt-manager: Fix detection for SLE15
  virtinst-add-sle15-detection-support.patch
  virtinst-add-caasp-support.patch
  virtinst-detect-oes-distros.patch
  virtinst-add-pvh-support.patch
  virtinst-s390x-disable-graphics.patch
  virtinst-set-qemu-emulator.patch
* Wed Jul 10 2019 carnold@suse.com
- Upstream bug fix (bsc#1027942)
  3c6e8537-guest-fix-warning-message-when-machine-type-is-changed-for-secure-boot.patch
* Fri Jul  5 2019 carnold@suse.com
- Update to virt-manager 2.2.1 (fate#326786)
  virt-manager-2.2.1.tar.bz2
  * CVE-2019-10183: Replace –unattended user-password and admin-password with user-password-file and admin-password-file (Fabiano Fidêncio)
  * Consistent –memballoon default across non-x86 (Andrea Bolognani)
  * virt-install: add –numatune memnode.* (Athina Plaskasoviti)
  * Drop hard dep on gtksourceview4, gtksourceview3 is fine as well
- Drop patches no longer needed
  033e9702-xmleditor-Handle-gtksourceview3-as-well-as-gtksourceview4.patch
  51d28f04-unattended-Dont-log-user-admin-passwords.patch
  5312a961-virt-install-Revive-wait-0-as-alias-for-noautoconsole.patch
  58c68764-unattended-Read-the-passwords-from-a-file.patch
* Wed Jul  3 2019 carnold@suse.com
- bsc#1140211 - VUL-1: CVE-2019-10183: virt-manager: unattended
  option leaks password via command line argument
  58c68764-unattended-Read-the-passwords-from-a-file.patch
  51d28f04-unattended-Dont-log-user-admin-passwords.patch
- Upstream bug fix (bsc#1027942)
  5312a961-virt-install-Revive-wait-0-as-alias-for-noautoconsole.patch
* Mon Jun 17 2019 carnold@suse.com
- Update to virt-manager 2.2.0 (fate#326786)
  virt-manager-2.2.0.tar.bz2
  * libvirt XML viewing and editing UI for new and existing domain, pools, volumes, networks
  * virt-install: libosinfo –unattended support (Fabiano Fidêncio, Cole Robinson)
  * Improve CPU model security defaults (Pavel Hrdina)
  * virt-install: new –install option. Ex: virt-install –install fedora29
  * virt-install: new –install kernel=,initrd=
  * virt-install: –disk, –memory, –name defaults from libosinfo (Fabiano Fidêncio, Cole Robinson)
  * virt-install: add device suboption aliases which consistently match libvirt XML naming
  * virt-xml: new –start, –no-define options (Marc Hartmayer)
  * virt-install: Add driver_queues argument to –controller (Vasudeva Kamath)
  * RISC-V support (Andrea Bolognani)
  * Device default improvements for non-x86 KVM (Andrea Bolognani)
  * Redesigned ‘New Network’ wizard
  * libguestfs inspection improvements (Pino Toscano)
  * virt-install: Add support for xenbus controller (Jim Fehlig)
  * cli: Add –disk wwn=,rawio= (Athina Plaskasoviti)
  * cli: Add –memballoon autodeflate=,stats.period= (Athina Plaskasoviti)
  * cli: Add –iothreads (Athina Plaskasoviti)
  * cli: Add –numatune memory.placement (Athina Plaskasoviti)
  * cli: Add –launchSecurity option (Erik Skultety)
  * cli: Fill in –memorybacking options
  * cli: –smartcard: support database= and certificate[0-9]*=
  * cli: –sysinfo: Add chasis suboptions
  * cli: –metadata: add genid= and genid_enable=
  * cli: –vcpus: add vcpus.vcpu[0-9]* config
  * cli: fill in all common char source options for –serial, –parellel, –console, –channel, –smartcard, –rng, –redirdev
  033e9702-xmleditor-Handle-gtksourceview3-as-well-as-gtksourceview4.patch
  virtman-dont-specify-gtksource-version.patch
- Drop patches no longer needed
  f7508d02-addhardware-Fix-setting-optimal-default-net-model.patch
  1018ab44-inspection-handle-failures-in-application-listing.patch
  ae8a4f3d-engine-Fix-first-run-startup-error.patch
  57db4185-virt-clone-fix-force-copy-of-empty-cdrom-or-floppy-disk.patch
  26a433fc-virtManager-clone-check-which-storage-pools-supports-volume-cloning.patch
  4f66c423-cloner-Handle-nonsparse-for-qcow2-images.patch
  a02fc0d0-virtManager-clone-build-default-clone-path-if-we-know-how.patch
  1856c1fa-support-Fix-minimum-version-check.patch
  001-adf30349-cli-refactor-get_prop.patch
  002-60c7e778-xmlapi-add-set_prop.patch
  003-5bad22e8-tests-Use-get-set_prop.patch
  004-ee5f3eab-support-Add-SUPPORT_CONN_DEVICE_BOOT_ORDER.patch
  005-7768eb17-cli-Add-check-if-device-boot-order-is-supported.patch
  006-ecc0861c-tests-xmlparse-refactor-method-for-generating-out-file-path.patch
  007-c9d070da-guest-Add-reorder_boot_order-method.patch
  008-1b535940-tests-Add-test-case-for-reorder_boot_order-method.patch
  009-b83a0a61-cli-Use-reorder_boot_order-for-setting-the-boot-order.patch
  010-c896d19d-tests-cli-Add-boot.order-tests.patch
  011-29f9f2ac-virt-xml-Add-no-define-argument.patch
  012-c2bff509-tests-cli-Add-test-case-for-no-define-argument.patch
  013-90b1a3ab-virt-xml-Add-support-for-starting-the-domain.patch
  014-908b8e8d-tests-virt-xml-Add-test-cases-for-start-option.patch
  5bc847eb-virt-install-Do-not-warn-about-consoles-on-s390x.patch
  74bbc3db-urldetect-Check-also-for-treeinfo.patch
  708af01c-osdict-Add-supports_virtioinput.patch
  f23b01be-guest-Add-VirtIO-input-devices-to-s390x-guests-with-graphics.patch
  7afbb90b-virt-xml-Handle-VM-names-that-look-like-id-uuid.patch
  8d9743d6-virt-install-Add-support-for-xenbus-controller.patch
  a0ca387a-cli-Fix-pool-default-when-path-belongs-to-another-pool.patch
  578451fe-urldetect-Dont-run-regex-against-None-SUSE-product-name.patch
  virtman-default-guest-from-host-os.patch
  virtman-prevent-double-click-starting-vm-twice.patch
* Thu Jun 13 2019 carnold@suse.com
- bsc#1138110 - XEN guest can not be restored from virt-manager
  after it is saved
  virtman-fix-restore-vm-menu-selection.patch
- Upstream bug fix (bsc#1027942)
  578451fe-urldetect-Dont-run-regex-against-None-SUSE-product-name.patch
* Mon Jun  3 2019 carnold@suse.com
- Make sure the old qemu-dm is not used for installing VMs. It
  can't handle direct kernel boot. (bsc#1125725)
  virtinst-set-qemu-emulator.patch
* Thu May 23 2019 carnold@suse.com
- jsc#SLE-6262, fate#327048: KVM: Boot Configuration Override
  001-adf30349-cli-refactor-get_prop.patch
  002-60c7e778-xmlapi-add-set_prop.patch
  003-5bad22e8-tests-Use-get-set_prop.patch
  004-ee5f3eab-support-Add-SUPPORT_CONN_DEVICE_BOOT_ORDER.patch
  005-7768eb17-cli-Add-check-if-device-boot-order-is-supported.patch
  006-ecc0861c-tests-xmlparse-refactor-method-for-generating-out-file-path.patch
  007-c9d070da-guest-Add-reorder_boot_order-method.patch
  008-1b535940-tests-Add-test-case-for-reorder_boot_order-method.patch
  009-b83a0a61-cli-Use-reorder_boot_order-for-setting-the-boot-order.patch
  010-c896d19d-tests-cli-Add-boot.order-tests.patch
  011-29f9f2ac-virt-xml-Add-no-define-argument.patch
  012-c2bff509-tests-cli-Add-test-case-for-no-define-argument.patch
  013-90b1a3ab-virt-xml-Add-support-for-starting-the-domain.patch
  014-908b8e8d-tests-virt-xml-Add-test-cases-for-start-option.patch
* Tue Apr  9 2019 carnold@suse.com
- Drop unneeded 0003-virtinst-python3-avoid-using-long-type.patch
  Drop Requires on python3-six
* Wed Apr  3 2019 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  57db4185-virt-clone-fix-force-copy-of-empty-cdrom-or-floppy-disk.patch
  26a433fc-virtManager-clone-check-which-storage-pools-supports-volume-cloning.patch
  4f66c423-cloner-Handle-nonsparse-for-qcow2-images.patch
  a02fc0d0-virtManager-clone-build-default-clone-path-if-we-know-how.patch
  1856c1fa-support-Fix-minimum-version-check.patch
  74bbc3db-urldetect-Check-also-for-treeinfo.patch
  708af01c-osdict-Add-supports_virtioinput.patch
  f23b01be-guest-Add-VirtIO-input-devices-to-s390x-guests-with-graphics.patch
  7afbb90b-virt-xml-Handle-VM-names-that-look-like-id-uuid.patch
  a0ca387a-cli-Fix-pool-default-when-path-belongs-to-another-pool.patch
* Mon Mar 25 2019 carnold@suse.com
- bsc#1126325 - L3: No way to set max_grant_frames for domUs via
  libvirt
  8d9743d6-virt-install-Add-support-for-xenbus-controller.patch
- bsc#1129176 - SLES 12 SP4 - kvm virt-install using ttyS0 leads to
  user process fault and interrupts installation (virt-manager)
  5bc847eb-virt-install-Do-not-warn-about-consoles-on-s390x.patch
* Thu Mar 14 2019 carnold@suse.com
- bsc#1129309 - Missing .treeinfo file on the media for CaaSP
  virtinst-add-caasp-support.patch
* Wed Mar 13 2019 carnold@suse.com
- Add detection for Caasp 4.0
  virtinst-media-detection.patch
* Wed Feb 20 2019 carnold@suse.com
- Temporarily disable Xen PVH support until feature is more usable
  (bsc#1125889)
  virtinst-add-pvh-support.patch
* Tue Feb 12 2019 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  f7508d02-addhardware-Fix-setting-optimal-default-net-model.patch
  1018ab44-inspection-handle-failures-in-application-listing.patch
  ae8a4f3d-engine-Fix-first-run-startup-error.patch
* Mon Feb  4 2019 carnold@suse.com
- Update to virt-manager 2.1.0 (fate#326786)
  virt-manager-2.1.0.tar.bz2
  virtman-fix-env-script-interpreter.patch
  * Bash autocompletion support (Lin Ma, Cole Robinson)
  * UI and command line –vsock support (Slavomir Kaslev)
  * virt-xml: Add –os-variant option (Andrea Bolognani)
  * virt-install: use libosinfo cpu, mem, disk size defaults (Fabiano Fidencio)
  * virt-install: Better usage of libosinfo -unknown distro IDs (Fabiano Fidencio)
  * virt-install: More usage of libosinfo for ISO –location detection
  * virt-install: Add –location LOCATION,kernel=X,initrd=Y for pointing to kernel/initrd in media that virt-install/libosinfo fails to detect
- Drop
  25b88733-urldetect-Dont-overload-suse_content-variable.patch
  9308bae3-util-Fix-typo-vpcu-vcpu.patch
  b8aff280-virtinst-quickfix-ubuntu-net-preseed-insert-cdrom-error.patch
  c30b3bc6-increase-timeout-for-vm-to-start.patch
  virtinst-use-latest-opensuse-version-when-unknown-media.patch
* Fri Feb  1 2019 carnold@suse.com
- bsc#1123942 - [XEN][Build157.1] failed to open file
  '/usr/lib/grub2/x86_64-xen/grub.xen during bootup PV guest
  virtinst-change-location-for-grub_xen.patch
* Wed Jan  9 2019 carnold@suse.com
- Increase the timeout for a vm to start before assuming something
  is wrong. (bsc#1027942)
  c30b3bc6-increase-timeout-for-vm-to-start.patch
* Mon Dec 17 2018 carnold@suse.com
- fate#326698: Add support for Xen's PVH guest type
  virtinst-add-pvh-support.patch
* Mon Dec  3 2018 Stasiek Michalski <hellcp@mailbox.org>
- Change icons to those provided by package
  (yast2-theme doesn't provide some icons anymore)
  virt-install.desktop
* Thu Nov 29 2018 carnold@suse.com
- bsc#1117846 - virt-manager: Checking for virtualization packages
  error
  virtman-load-stored-uris.patch
* Tue Nov 27 2018 carnold@suse.com
- bsc#1116990 - [virt-install] internal error: libxenlight failed
  to create new domain 'sles-11-sp4-64-pv-def-net'. Fix reversed
  logic when testing for i386.
  virtinst-use-xenpae-kernel-for-32bit.patch
* Tue Oct 30 2018 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  b8aff280-virtinst-quickfix-ubuntu-net-preseed-insert-cdrom-error.patch
  25b88733-urldetect-Dont-overload-suse_content-variable.patch
  9308bae3-util-Fix-typo-vpcu-vcpu.patch
* Tue Oct 30 2018 carnold@suse.com
- Update to virt-manager 2.0.0 (fate#326786)
  virt-manager-2.0.0.tar.bz2
  * Finish port to Python 3 (Radostin Stoyanov, Cole Robinson)
  * Improved VM defaults for supported OS: q35 PCIe, usb3, CPU host-model
  * Search based OS selection UI for new VMs (Daniel P. Berrangé, Cole Robinson)
  * Track OS name for lifetime of domain in XML
  * Host interface management UI has been completely removed
  * Show domain IP on interface details page (Lin Ma, Cole Robinson)
  * More efficient stats polling with AllDomainStats (Simon Kobyda, Cole Robinson)
  * TPM device model and backend UI (Marc-André Lureau, Stefan Berger)
  * Show connection state in UI (Lin Ma)
  * Show attached devices in UI (Lin Ma)
  * UI option to plug/unplug VM nic link (Simon Kobyda)
  * UI support for disk discard and detect_zeroes (Povilas Kanapickas, Lin Ma)
  * Improved SUSE –location URL/ISO detection (Charles Arnold)
  * cli and UI support for SCSI persistent reservations (Lin Ma)
  * cli: Add –network mtu.size= option (Anya Harter)
  * cli: Add –disk driver.copy_on_read (Anya Harter)
  * cli: Add –disk geometry support (Anya Harter)
  * cli: Add –sound codec support (Anya Harter)
  * cli: Add –hostdev net/char/block for LXC (Lubomir Rintel)
  * cli: Add –memorybacking access_mode and source_type (Marc-André Lureau)
  * cli: Add –boot rebootTimout (Yossi Ovadia)
  * cli: Add –boot bootloader=
  * cli: Add –destroy-on-exit
- Drop patches contained in new tarball or not required
  0004-virtinst-python3-use-binary-mode-for-kernel.patch
  27d4b167-virtinst-update-location-for-opensuse.patch
  5a7698c7-fix-select-network-vol.patch
  d15b78ab-virtinst-read-CPU-model-from-domain-capabilities.patch
  fd6a8154-virtinst-compare-host-and-domain-cpu-models.patch
  5a7698c7-fix-select-network-vol.patch
  virtcli-python2-to-python3-conversion.patch
  virtinst-add-ppc64-arch-support.patch
  virtinst-check-date-format.patch
  virtinst-fix-sle-distro-parsing.patch
  virtinst-handle-tumbleweed-treeinfo-file.patch
  virtinst-nfs-install-sanitize.patch
  virtinst-no-usb-tablet-for-xenpv.patch
  virtinst-set-qemu-emulator.patch
  virtinst-storage-ocfs2.patch
  virtman-add-connect-default.patch
  virtman-fix-missing-translations.patch
  virtman-libvirtd-not-running.patch
  virtman-packages.patch
  virtmisc-python2-to-python3-conversion.patch
* Mon Oct 22 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- boo#1112729 - Add missing python3-six dep introduced by patch
  0003-virtinst-python3-avoid-using-long-type.patch
* Mon Oct 15 2018 James Fehlig <jfehlig@suse.com>
- Fix selection of network volumes (bsc#1100558)
  5a7698c7-fix-select-network-vol.patch
* Mon Oct 15 2018 Klaus Kämpf <kkaempf@suse.com>
- Remove hard dependency on openSUSE branding by changing it to a
  recommends
* Fri Jul 13 2018 carnold@suse.com
- Fix sle15 detection because of changes in osinfo-db (bsc#1054986)
  virtinst-add-sle15-detection-support.patch
* Wed Jun 20 2018 carnold@suse.com
- bsc#1096819 - virt-install - Couldn't find hvm kernel for SUSE
  tree
  virtinst-python2-to-python3-conversion.patch
* Tue Jun 19 2018 carnold@suse.com
- bsc#1098054 - osinfo-query and virt-install do not detect
  caasp3.0
  virtinst-add-caasp-support.patch
* Thu May 31 2018 carnold@suse.com
- bsc#1081544 - SLEx_15_LOC : YaST: ALL_LANGS:Untranslated text
  'Options' in Virtualization/Create a new Virtual Machine/Network
  Install (HTTP...)/Step 2 of 5 dialog
- bsc#1081542 - SLEx_15_LOC : YaST: ALL_LANGS:Untranslated text.
  Translation fix included in new tarball.
  virtman-fix-missing-translations.patch
* Mon May 21 2018 carnold@suse.com
- Update to virt-manager 1.5.1 (bsc#1027942). This was a quick bug
  bugfix release that came out shortly after version 1.5.0
  virt-manager-1.5.1.tar.bz2
- Drop 4c7c4590-manager-Fix-mem-disk-net-stats-graphs.patch
* Thu Apr 26 2018 carnold@suse.com
- bsc#1091113 - virt-install errs with: No option 'version' in
  section: 'general
  virtinst-handle-tumbleweed-treeinfo-file.patch
* Tue Apr  3 2018 carnold@suse.com
- bsc#1086038 - VM guests cannot be properly installed with
  virt-install
  d15b78ab-virtinst-read-CPU-model-from-domain-capabilities.patch
  fd6a8154-virtinst-compare-host-and-domain-cpu-models.patch
- Drop virtinst-dont-set-cpu-model-when-caps-mismatch.patch in
  favor of upstream versions.
* Thu Mar 29 2018 carnold@suse.com
- Fallback to latest version of openSUSE when opensuse-unknown is
  detected for the ISO (bsc#1085757)
  virtinst-use-latest-opensuse-version-when-unknown-media.patch
* Thu Mar 22 2018 carnold@suse.com
- bsc#1086038 - VM guests cannot be properly installed with
  virt-install
  virtinst-dont-set-cpu-model-when-caps-mismatch.patch
* Wed Mar  7 2018 carnold@suse.com
- bsc#1067018 - L3: KVM Guest creation failed - Property .cmt not
  found
  virtinst-dont-use-special-copy-cpu-features.patch
- Upstream bug fix (bsc#1027942)
  27d4b167-virtinst-update-location-for-opensuse.patch
* Mon Mar  5 2018 jengelh@inai.de
- Replace old $RPM_* shell vars. Use %%_datadir more consistently.
* Fri Feb  9 2018 carnold@suse.com
- Upstream bug fix (bsc#1027942)
  4c7c4590-manager-Fix-mem-disk-net-stats-graphs.patch
* Wed Feb  7 2018 carnold@suse.com
- Update to virt-manager 1.5.0 (bsc#1027942)
  virt-manager-1.5.0.tar.bz2
  * python3 prep work (Radostin Stoyanov, Cole Robinson, Cédric Bosdonnat)
  * Switch –location ISO to use isoinfo (Andrew Wong)
  * virt-install: add –cpu numa distance handling (Menno Lageman)
  * virt-install: fix –disk for rbd volumes with auth (Rauno Väli)
  * virt-install: add –cputune vcpupin handling (Wim ten Have)
  * details ui: Showing attached scsi devices per controller (Lin Ma)
  * network ui: Show details about SR-IOV VF pool (Lin Ma)
  * Greatly expand UI test suite coverage
- Dropped patches
  0001-Improve-container-image-url-example.patch
  0001-py3-store-exception-variables-for-use-outside-except.patch
  0002-create-wizard-fix-alignment-in-os-container-page.patch
  0003-oscontainer-ask-root-password-in-the-wizard.patch
  0004-Harmonize-invisible_char-values.patch
  083dfcc8-Show-details-about-the-network-of-SR-IOV-VF-pool.patch
  08a58d61-pycodestyle-remove-description-of-fixed-errors.patch
  0c6bcb09-fix-bytes-string-mess-in-serial-console.patch
  0e812e3c-dont-skip-authentication-for-listen-type-none-with-fixed-QEMU.patch
  23aaf852-network-Set-bridge-name-to-None-instead-of-blank.patch
  2d276ebe-progress-dont-overwrite-format.patch
  2eb455c9-correctly-calculate-virtio-scsi-controller-index.patch
  374a3779-urlfetcher-write-test-file-as-binary-content.patch
  37ea5207-replace-StandardError-with-Exception.patch
  3b769643-dont-add-URI-into-params-for-tunneled-migration.patch
  3be78d1f-addhardware-dont-allow-panic-option-where-not-supported.patch
  44de92b7-use-reload-from-imp-module.patch
  63fce081-pycodestyle-Use-isinstance-for-type-checking.patch
  67122615-python2to3-division-compatability.patch
  69c84bea-import-reduce-from-functools-module.patch
  6dfc4de1-add-support-for-parsing-formatting-SR-IOV-VFs.patch
  6e6f59e7-diskbackend-get-a-proper-size-of-existing-block-device-while-cloning.patch
  73de8285-systray-remove-redundant-variable-assignment.patch
  75210ed3-replace-StringIO-with-io.patch
  7f1b4cee-pycodestyle-fix-all-E125-warnings.patch
  7fc7e94f-fix-virtio-scsi-controller-target-calculation.patch
  91c0669c-cli-Fix-OrderedDict-mutated-during-iteration-on-python3.patch
  9617d126-systray-Use-APPLICATION_STATUS-for-appindicator.patch
  999dbb36-cli-Make-VirtCLIArgument-instantiation-less-crazy.patch
  9a9f9ecd-ignore-comments-in-keymap-conf-files.patch
  a2bcd6c4-dont-compare-between-None-and-int.patch
  b5b2433a-baseclass-Fix-UI-file-loading-on-py3.patch
  b8fa0c6b-xmlnsqemu-order-XML-output-like-libvirt-does.patch
  b9bc3b60-undefine-only-persistent-domain.patch
  bc3c9a9d-progress-remove-unused-import.patch
  bc8c5b07-append--attach-to-virt-viewer-if-graphics-has-listen-type-none.patch
  c174b550-connection-Another-py3-exception-variable-fix.patch
  d1e1cf64-progress-remove-trailing-white-space.patch
  d2648d81-virtconv-dont-implicitly-depend-on-dict-hash-order.patch
  d82022bd-manager-drop-python2-only-cmp-usage.patch
  dff00d4f-remove-deprecated-statvfs-module.patch
  e2ad4b2f-convert-iteritems-to-items.patch
  e73abe5a-diskbackend-convert-to-long-the-calculated-size.patch
  f41aafc7-Use-enumerate-instead-of-range-and-len.patch
  f7c8cf9f-devicepanic-dont-return-empty-model-list.patch
  f836e47b-virtinst-Fix-URLFetcher-for-reading-files.patch
* Tue Feb  6 2018 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  b5b2433a-baseclass-Fix-UI-file-loading-on-py3.patch
  0c6bcb09-fix-bytes-string-mess-in-serial-console.patch
  bc8c5b07-append--attach-to-virt-viewer-if-graphics-has-listen-type-none.patch
  0e812e3c-dont-skip-authentication-for-listen-type-none-with-fixed-QEMU.patch
  67122615-python2to3-division-compatability.patch
- Dropped in favor of upstream version
  0001-virtinst-python3-terminal-width-should-be-int.patch
  python3-fix-bytes-string-mess-in-serial-console.patch
* Mon Feb  5 2018 carnold@suse.com
- Default to sles15 and opensuse15 as the 'preferred_distros' for
  this release. (bsc#1054986)
  virtinst-osdict-get_supported.patch
  virt-manager.spec
* Wed Jan 24 2018 bjorn.lie@gmail.com
- Replace conditional gtk2-tools with gtk3-tools BuildRequires.
  (bsc#1070896)
* Tue Jan 16 2018 cbosdonnat@suse.com
- Fix a python3 UnboundLocalError (bsc#1075622)
  c174b550-connection-Another-py3-exception-variable-fix.patch
* Fri Jan  5 2018 carnold@suse.com
- bsc#1072012 - openSUSE Tumbleweed, virt-manager: Opening VM GUI
  fails with "ordinal not in range" (bart.vanassche+novell@gmail.com)
- bsc#1074808 - [beta4+maintain update][virt-manager] Error
  launching details:'ascii' codec can't decode byte
  virtman-python2-to-python3-conversion.patch
* Tue Jan  2 2018 carnold@suse.com
- bsc#1074056 - [build 408.1]virt-install tool reports "TypeError:
  must use keyword argument for key function" when parsing vnc
  virtinst-python2-to-python3-conversion.patch
* Tue Jan  2 2018 cbosdonnat@suse.com
- Downgrade python3-virt-bootstrap Recommends to Suggests to
  minimize the number of default dependencies. (bsc#1073937)
* Wed Dec 20 2017 cbosdonnat@suse.com
- Get rid of "TypeError: Couldn't find foreign struct converter for
  'cairo.Context'" errors by adding a dependency to python3-cairo.
  (bsc#1062865)
- Python3: Fix 'local variable 'e' referenced before assignment'
  0001-py3-store-exception-variables-for-use-outside-except.patch
  (bsc#1073594)
* Tue Dec 19 2017 carnold@suse.com
- Fix TypeError in inspection.py (bsc#1070896)
  virtman-python2-to-python3-conversion.patch
- Fix openSUSE 15.0 detection. It has no content file or .treeinfo
  file (bsc#1054986)
  virtinst-add-sle15-detection-support.patch
* Wed Dec 13 2017 cbosdonnat@suse.com
- Fix display and input of text in serial console (bsc#1070896)
  python3-fix-bytes-string-mess-in-serial-console.patch
- Fix virt-bootstrap UI integration (bsc#1063367)
  0001-Improve-container-image-url-example.patch
  0002-create-wizard-fix-alignment-in-os-container-page.patch
  0003-oscontainer-ask-root-password-in-the-wizard.patch
  0004-Harmonize-invisible_char-values.patch
* Mon Dec 11 2017 carnold@suse.com
- bsc#1071825 - AttributeError: 'NoneType' object has no attribute
  'change_run_text'
  virtman-register-delete-event-for-details-dialog.patch
* Thu Dec  7 2017 cbosdonnat@suse.com
- bsc#1070896 - virt-manager will not run on a python3 only system
  remove obsolete python-gconf dependency. This one was also pulling
  python2.
* Thu Dec  7 2017 mwilck@suse.com
- More fixes for python3 (bsc#1070896)
  0001-virtinst-python3-terminal-width-should-be-int.patch
  0002-virtinst-python3-avoid-comparison-of-None-and-int.patch
  0003-virtinst-python3-avoid-using-long-type.patch
  0004-virtinst-python3-use-binary-mode-for-kernel.patch
* Sat Dec  2 2017 carnold@suse.com
- bsc#1070896 - virt-manager will not run on a python3 only system
  virtcli-python2-to-python3-conversion.patch
  virtconv-python2-to-python3-conversion.patch
  virtinst-python2-to-python3-conversion.patch
  virtman-python2-to-python3-conversion.patch
  virtmisc-python2-to-python3-conversion.patch
  virttests-python2-to-python3-conversion.patch
* Tue Nov 28 2017 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  b9bc3b60-undefine-only-persistent-domain.patch
  7fc7e94f-fix-virtio-scsi-controller-target-calculation.patch
  2eb455c9-correctly-calculate-virtio-scsi-controller-index.patch
* Fri Nov 24 2017 carnold@suse.com
- bsc#1067263 - virt-install: ERROR unicode argument expected, got
  'str'
  f836e47b-virtinst-Fix-URLFetcher-for-reading-files.patch
- Drop virtinst-fix-replace-StringIO-with-io.patch
* Wed Nov  8 2017 carnold@suse.com
- bsc#1067263 - virt-install: ERROR unicode argument expected, got
  'str'
  virtinst-fix-replace-StringIO-with-io.patch
* Fri Oct 27 2017 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  9a9f9ecd-ignore-comments-in-keymap-conf-files.patch
  9617d126-systray-Use-APPLICATION_STATUS-for-appindicator.patch
  e73abe5a-diskbackend-convert-to-long-the-calculated-size.patch
  6e6f59e7-diskbackend-get-a-proper-size-of-existing-block-device-while-cloning.patch
  23aaf852-network-Set-bridge-name-to-None-instead-of-blank.patch
  d1e1cf64-progress-remove-trailing-white-space.patch
  63fce081-pycodestyle-Use-isinstance-for-type-checking.patch
  08a58d61-pycodestyle-remove-description-of-fixed-errors.patch
  bc3c9a9d-progress-remove-unused-import.patch
  2d276ebe-progress-dont-overwrite-format.patch
  e2ad4b2f-convert-iteritems-to-items.patch
  dff00d4f-remove-deprecated-statvfs-module.patch
  75210ed3-replace-StringIO-with-io.patch
  a2bcd6c4-dont-compare-between-None-and-int.patch
  44de92b7-use-reload-from-imp-module.patch
  69c84bea-import-reduce-from-functools-module.patch
  37ea5207-replace-StandardError-with-Exception.patch
  f41aafc7-Use-enumerate-instead-of-range-and-len.patch
  91c0669c-cli-Fix-OrderedDict-mutated-during-iteration-on-python3.patch
  b8fa0c6b-xmlnsqemu-order-XML-output-like-libvirt-does.patch
  d2648d81-virtconv-dont-implicitly-depend-on-dict-hash-order.patch
  999dbb36-cli-Make-VirtCLIArgument-instantiation-less-crazy.patch
  7f1b4cee-pycodestyle-fix-all-E125-warnings.patch
  d82022bd-manager-drop-python2-only-cmp-usage.patch
  374a3779-urlfetcher-write-test-file-as-binary-content.patch
  f7c8cf9f-devicepanic-dont-return-empty-model-list.patch
  3be78d1f-addhardware-dont-allow-panic-option-where-not-supported.patch
  73de8285-systray-remove-redundant-variable-assignment.patch
* Wed Oct 11 2017 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  3b769643-dont-add-URI-into-params-for-tunneled-migration.patch
  6dfc4de1-add-support-for-parsing-formatting-SR-IOV-VFs.patch
  083dfcc8-Show-details-about-the-network-of-SR-IOV-VF-pool.patch
- Add Recommends: python3-virt-bootstrap
  Change 'Requires: libvirt-python' to 'Requires: python-libvirt-python'
  virt-manager.spec
- Add corrections to sle15 detection (bsc#1054986)
* Wed Sep 20 2017 carnold@suse.com
- Update to virt-manager 1.4.3 (bsc#1027942)
  virt-manager-1.4.3.tar.bz2
  * Improve install of debian/ubuntu non-x86 media (Viktor Mihajlovski, Andrew Wong)
  * New virt-install –graphics listen.* (Pavel Hrdina)
  * New virt-install –disk snapshot_policy= (Pavel Hrdina)
  * New virt-install –cpu cache.* (Lin Ma)
  * Several bug fixes
- Dropped the following patch contained in new tarball
  e902fa55-force-binary-mode-with-FTP-servers.patch
* Fri Sep 15 2017 carnold@suse.com
- Add .treeinfo detection for SUSE distros (bsc#1054986)
  virtinst-add-sle15-detection-support.patch
* Thu Sep 14 2017 carnold@suse.com
- bsc#1058666 - virt-manager has a dependency on
  typelib(AppIndicator3) = 0.1
  virt-manager.spec
* Tue Aug 29 2017 carnold@suse.com
- bsc#1056028 - Not able to install OES2018 as guest on Xen
  virtinst-detect-oes-distros.patch
* Fri Aug 25 2017 carnold@suse.com
- bsc#1055787 - virt-install: With PV ISO installs guests will hang
  on first reboot
  virtinst-keep-install-iso-attached.patch
* Thu Aug 24 2017 carnold@suse.com
- bsc#1054986 - Missing /media.1/products file on the ISO media
  causes virt-install to fail detecting distro type and version
  virtinst-add-sle15-detection-support.patch
* Tue Aug 22 2017 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  e902fa55-force-binary-mode-with-FTP-servers.patch
* Wed Aug  9 2017 carnold@suse.com
- Update to virt-manager 1.4.2 (bsc#1027942)
  virt-manager-1.4.2.tar.bz2
  virtinst-check-date-format.patch
  virtinst-no-usb-tablet-for-xenpv.patch
  * New VM wixard virt-bootstrap integration (Radostin Stoyanov)
  * New VM wizard support for virtuozzo containers (Mikhail Feoktistov)
  * network UI: add support to create SR-IOV VF pool (Lin Ma)
  * Nicer OS list in New VM wizard (Pino Toscano)
  * Better defaults for UEFI secureboot builds (Pavel Hrdina)
  * Fix defaults for aarch64 VMs if graphics are requested
  * virt-install: new –memdev option (Pavel Hrdina)
  * virt-install: add –disk logical/physical_block_size (Yuri Arabadji)
  * virt-install: add –features hyperv_reset=, hyperv_synic= (Venkat Datta N H)
- Dropped the following patches contained in new tarball
  f5d709d9-lang-it-1.patch
  c66098f3-lang-it-2.patch
  452a693e-lang-update.patch
  6b5106ea-lang-it-ko-fix.patch
  9c8ffe51-fix-multiple-warnings-1.patch
  cb182f7e-skip-authentication-only-for-VNC-with-listen-type-none.patch
  0610cd6a-ensure-bool-value-used-for-set_sensitive-call.patch
  f341352c-remove-redundant-error-string.patch
  ff3b4dc5-dont-overwrite-install-bootorder.patch
  2099a194-reset-guest-domain-to-none-on-domain-creation-error.patch
  93085d2b-reset-guest-domain-to-none-on-domain-creation-error.patch
  7aee124d-fix-multiple-warnings-2.patch
  f38c56c9-add-support-for-SMM-feature.patch
  24f9d053-add-support-for-loader-secure-attribute.patch
  4f8e795c-if-required-by-UEFI-enable-SMM-feature-and-set-q35-machine-type.patch
  b690908a-enable-secure-feature-together-with-smm-for-UEFI.patch
  virtinst-expand-combobox.patch
* Tue Aug  1 2017 jfehlig@suse.com
- Add a supportconfig plugin
  virt-manager-supportconfig
  FATE#323661
* Wed Jun  7 2017 carnold@suse.com
- bsc#1042709 - unable to create VM with SLE4SAP SP1 over network
  install
  virtinst-fix-sle-distro-parsing.patch
* Mon Jun  5 2017 carnold@suse.com
- bsc#1027942 - virt-manager: Missing upstream bug fixes
  f38c56c9-add-support-for-SMM-feature.patch
  24f9d053-add-support-for-loader-secure-attribute.patch
  4f8e795c-if-required-by-UEFI-enable-SMM-feature-and-set-q35-machine-type.patch
  b690908a-enable-secure-feature-together-with-smm-for-UEFI.patch
* Thu May 25 2017 carnold@suse.com
- bsc#1027942 - virt-manager: Missing upstream bug fixes
  93085d2b-reset-guest-domain-to-none-on-domain-creation-error.patch
* Mon May  8 2017 carnold@suse.com
- bsc#1037958 - Guest "sles-11-sp3 32bit PV" is failed to boot up
  Don't use 64bit grub.xen to boot 32bit PV guest
  virtinst-pvgrub2-bootloader.patch
* Thu Apr 27 2017 carnold@suse.com
- bsc#1027942 - virt-manager: Missing upstream bug fixes
  f5d709d9-lang-it-1.patch
  c66098f3-lang-it-2.patch
  452a693e-lang-update.patch
  6b5106ea-lang-it-ko-fix.patch
  9c8ffe51-fix-multiple-warnings-1.patch
  cb182f7e-skip-authentication-only-for-VNC-with-listen-type-none.patch
  0610cd6a-ensure-bool-value-used-for-set_sensitive-call.patch
  f341352c-remove-redundant-error-string.patch
  ff3b4dc5-dont-overwrite-install-bootorder.patch
  2099a194-reset-guest-domain-to-none-on-domain-creation-error.patch
  7aee124d-fix-multiple-warnings-2.patch
* Mon Apr 24 2017 carnold@suse.com
- Check for SLE15 and Leap 15 bsc#1035779
  virtman-default-guest-from-host-os.patch
* Mon Apr 24 2017 jan.hilberath@suse.com
- Fix CaaSP detection (bsc#1010060)
  Allow installation of "SUSE Container as a Service Platform".
  virtinst-add-caasp-support.patch
- Dropped virtinst-add-casp-support.patch
* Wed Mar 15 2017 carnold@suse.com
- Fix initializing the default host installation source location
  (bsc#1027942)
  virtman-default-guest-from-host-os.patch
  virtman-show-suse-install-repos.patch
* Thu Mar  9 2017 carnold@suse.com
- Update to virt-manager 1.4.1 (bsc#1027942)
  virt-manager-1.4.1.tar.bz2
  * storage/nodedev event API support (Jovanka Gulicoska)
  * UI options for enabling spice GL (Marc-André Lureau)
  * Add default virtio-rng /dev/urandom for supported guest OS
  * Cloning and rename support for UEFI VMs (Pavel Hrdina)
  * libguestfs inspection UI improvements (Pino Toscano)
  * virt-install: Add –qemu-commandline
  * virt-install: Add –network vhostuser (Chen Hanxiao)
  * virt-install: Add –sysinfo (Charles Arnold)
- Dropped the following patches contained in new tarball
  0425975f-use-virDomainMigrate3-API.patch
  0910c8dc-black-display-if-graphic-mode-vnc-and-listen-type-none.patch
  1d2cd306-Fix-incorrect-usage-of-virtio-input.patch
  2df8dc39-detect-whether-IP-address-comes-from-DHCP-server.patch
  559e813b-xmlbuilder-02.patch
  561f5cd3-drop-xenmigr-scheme-from-Xen-migration-URI.patch
  5a11cf07-virt-manager-generates-invalid-guest-XML.patch
  617b9271-dont-return-virtio1.0-net-as-valid-device-name.patch
  63784f4d-document-new-sysinfo-option.patch
  6daff68a-fix-italian-lang-file.patch
  7962672c-fix-error-checking-extra_args.patch
  835ddc5f-xmlbuilder-04.patch
  a3206f89-Add-the-sysinfo-option.patch
  a931a1a6-xmlbuilder-03.patch
  b08647c2-xmlbuilder-05.patch
  b31c0b44-Add-classes-for-defining-SMBios-information.patch
  b4858842-fix-bad-version-check-regression.patch
  b8dccf6a-fix-connection-to-remote-spice-with-password.patch
  c5ce0ab5-connection-fix-transport-detection.patch
  d8a0a788-xmlbuilder-01.patch
  e69cc002-spice-catch-failure-to-setup-usbdev-manager.patch
  f07a3021-fix-wait-to-behave-like-noautoconsole.patch
  virtinst-add-default-rng-device.patch
* Fri Mar  3 2017 carnold@suse.com
- Upstream bug fixes (bsc#1027942)
  2df8dc39-detect-whether-IP-address-comes-from-DHCP-server.patch
  b8dccf6a-fix-connection-to-remote-spice-with-password.patch
  0910c8dc-black-display-if-graphic-mode-vnc-and-listen-type-none.patch
* Thu Jan 26 2017 carnold@suse.com
- bsc#1022173 - virt-manager: unknown input device type
  'virtio1.0-input'
  1d2cd306-Fix-incorrect-usage-of-virtio-input.patch
- bsc#1005848 - KVM: guest can not be started on top of SLES12SP1
  KVM host ppc64
  5a11cf07-virt-manager-generates-invalid-guest-XML.patch
- Upstream bug fixes
  617b9271-dont-return-virtio1.0-net-as-valid-device-name.patch
  7962672c-fix-error-checking-extra_args.patch
  b4858842-fix-bad-version-check-regression.patch
  f07a3021-fix-wait-to-behave-like-noautoconsole.patch
* Wed Jan 18 2017 carnold@suse.com
- bsc#1005861 - virt-manager create new machine dialog box too
  small to display system type
  virtinst-expand-combobox.patch
* Wed Jan 18 2017 carnold@suse.com
- bsc#976796 - Virt-manager does not show up in application menu
  virtman-desktop.patch
  virt-install.desktop
* Fri Jan 13 2017 carnold@suse.com
- bsc#1010060 - virt-install won't start CASP installation
  virtinst-add-casp-support.patch
* Fri Jan  6 2017 carnold@suse.com
- bsc#1018645 - virt-manager is using pygrub for booting PV domU
  virtinst-pvgrub2-bootloader.patch
* Thu Sep  8 2016 carnold@suse.com
- bsc#996020 - L3: Unable to migrate VMs between SLES12 SP1 XEN
  Hosts with virt-manager
  0425975f-use-virDomainMigrate3-API.patch
  561f5cd3-drop-xenmigr-scheme-from-Xen-migration-URI.patch
* Thu Sep  8 2016 carnold@suse.com
- fate#319621 - KVM: Provide SMBIOS info to KVM virtual machines
  d8a0a788-xmlbuilder-01.patch
  559e813b-xmlbuilder-02.patch
  a931a1a6-xmlbuilder-03.patch
  835ddc5f-xmlbuilder-04.patch
  b08647c2-xmlbuilder-05.patch
  b31c0b44-Add-classes-for-defining-SMBios-information.patch
  a3206f89-Add-the-sysinfo-option.patch
  63784f4d-document-new-sysinfo-option.patch
* Fri Aug 19 2016 carnold@suse.com
- bsc#994394 - virt-manager does not show up in SLE Classic
  "Applications" menu
  virtman-desktop.patch
* Wed Aug 17 2016 carnold@suse.com
- bsc#989639 - xen cdrom device pass-through fails to start FV
  guest
  virtinst-use-qemu-for-cdrom-device.patch
* Tue Jul 19 2016 carnold@suse.com
- bsc#989652 - Cannot create vms with virt-manager after upgrade
  from SLES11SP4 to SLES12SP2
  virtman-show-suse-install-repos.patch
* Mon Jun 20 2016 carnold@suse.com
- Update to virt-manager version 1.4.0 (fate#319990)
  virt-manager-1.4.0.tar.bz2
  e69cc002-spice-catch-failure-to-setup-usbdev-manager.patch
  c5ce0ab5-connection-fix-transport-detection.patch
  6daff68a-fix-italian-lang-file.patch
  virtman-dont-specify-vte-version.patch
  * virt-manager: spice GL console support (Marc-André Lureau, Cole Robinson)
  * Bump gtk and pygobject deps to 3.14
  * virt-manager: add checkbox to forget keyring password (Pavel Hrdina)
  * cli: add --graphics gl= (Marc-André Lureau)
  * cli: add --video accel3d= (Marc-André Lureau)
  * cli: add --graphics listen=none (Marc-André Lureau)
  * cli: add --transient flag (Richard W.M. Jones)
  * cli: --features gic= support, and set a default for it (Pavel Hrdina)
  * cli: Expose --video heads, ram, vram, vgamem
  * cli: add --graphics listen=socket
  * cli: add device address.type/address.bus/...
  * cli: add --disk seclabelX.model (and .label, .relabel)
  * cli: add -cpu cellX.id (and .cpus, and .memory)
  * cli: add --network rom_bar= and rom_file=
  * cli: add --disk backing_format=
  * Many bug fixes and improvements
  - Dropped the following
  virt-manager-1.3.2.tar.bz2
  89c3638b-fix-detection-that-libvirtd-is-stopped.patch
  21fd079e-replace-unar-with-other-archivers.patch
  eae7dc06-fix-URL-installs-when-content-length-header-missing.patch
  1c221fd0-suse-ovmf-paths.patch
  f11eb00b-virt-convert-decompress-gz-files-before-converting.patch
  8ba48f52-add-virtio-device-model-and-accel3d-attribute.patch
  f454798b-virtman-fix-making-screenshot.patch
  5ecc2b44-dont-clear-recommended-machine-if-none-is-selected.patch
  de9cd87f-return-recommended-machine-for-XEN.patch
  0acdea1d-show-firmware-options-also-for-XEN-guests.patch
  virtinst-fix-sle12sp1-detection.patch
  virtinst-fix-tumbleweed-detection.patch
* Tue Jun 14 2016 carnold@suse.com
- boo#981836 - virt-manager does not support all boot methods for
  AArch64
  5ecc2b44-dont-clear-recommended-machine-if-none-is-selected.patch
  de9cd87f-return-recommended-machine-for-XEN.patch
  0acdea1d-show-firmware-options-also-for-XEN-guests.patch
* Tue Jun  7 2016 carnold@suse.com
- bsc#983241 - Using eepro1000 emulated driver leads to 'eepro100'
  is not a valid device model name
  Drop virtman-eepro100.patch
- Remove unecessary hyphen '-' from tumbleweed name
  virtinst-fix-tumbleweed-detection.patch
* Tue Jun  7 2016 mvetter@suse.com
- boo#983482: Virt-Manager 1.3.2 cannot create screenshot.
  Use upstream patch from revision f454798b337aedb881671f62fe3b25fad703b768
- Add f454798b-virtman-fix-making-screenshot.patch
* Tue May 10 2016 carnold@suse.com
- bsc#978173 - Cannot install sles-10-sp4 on sles-12-sp1 host
  virtinst-use-xenpae-kernel-for-32bit.patch
* Fri May  6 2016 carnold@suse.com
- bsc#978937 - New qemu virtual virtio gpu not selectable in
  virt-manager
  8ba48f52-add-virtio-device-model-and-accel3d-attribute.patch
* Tue May  3 2016 carnold@suse.com
- fate#319659 - vm-install: remove shortcut in virt-manager
  Need to also remove spec file 'Recommends' for vm-install
  virt-manager.spec
* Mon Apr 25 2016 michael@stroeder.com
- bsc#975219 - virt-manager interface is broken
  (Tumbleweed-20160417)
  virt-manager.spec
* Tue Apr  5 2016 dimstar@opensuse.org
- Require yast2-branding-openSUSE by virt-manager: the icon
  yast-vm-management, explicitly set by virtman-desktop.patch, is
  shipped in this package.
* Wed Mar 30 2016 carnold@suse.com
- bsc#964407 - Virt-Manager: Installer wrongly detects SLE-12-GA
  media as SLE-12-SP1
  virtinst-fix-sle12sp1-detection.patch
* Wed Mar 23 2016 carnold@suse.com
- Replace virtinst-replace-unar-with-other-archivers.patch with the
  upstream version
  21fd079e-replace-unar-with-other-archivers.patch
* Fri Mar 18 2016 carnold@suse.com
- bsc#971825 - virt-manager needs to use grub.xen installing a PV
  Tumbleweed VM
  virtinst-pvgrub2-bootloader.patch
* Fri Mar 11 2016 lma@suse.com
- fate#320353 - Add the ability for virt-convirt to decompress
  compressed files in an OVA
  f11eb00b-virt-convert-decompress-gz-files-before-converting.patch
* Wed Mar  9 2016 carnold@suse.com
- bsc#951726 - Error - 'wrong number of arguments (3 for 1) ...'
  when attempting to create DomU through the yast
  virt-manager.spec
* Tue Feb  2 2016 carnold@suse.com
- bsc#964407 - Virt-Manager: Installer wrongly detects SLE-12-GA
  media as SLE-12-SP1
  virtinst-fix-sle12sp1-detection.patch
- Fix Tumbleweed detection
  virtinst-fix-tumbleweed-detection.patch
* Fri Jan 29 2016 jfehlig@suse.com
- bsc#961853 - virt-install doesn't work with option -boot uefi
  1c221fd0-suse-ovmf-paths.patch
* Wed Jan 27 2016 carnold@suse.com
- bsc#963692 - libvirtError: unsupported configuration: unknown
  driver format value 'block'
  virtinst-xen-drive-type.patch
- bsc#963173 - virt-manager - dependencies for VNC client are not
  met on PPC
  virt-manager.spec
* Mon Jan 18 2016 carnold@suse.com
- bsc#962221 - virt-install: 'NoneType' object has no attribute
  'isdigit'
  eae7dc06-fix-URL-installs-when-content-length-header-missing.patch
* Fri Jan  8 2016 carnold@suse.com
- bsc#960828 - Unable to create qcow2 volumes on remote KVM with
  virt-manager
  virtinst-vol-default-nocow.patch
- bsc#960724 - virt-manager fails to create Virtual machines on a
  CentOS7 host
  virtinst-set-qemu-emulator.patch
- Upstream bug fix
  89c3638b-fix-detection-that-libvirtd-is-stopped.patch
* Mon Jan  4 2016 carnold@suse.com
- Drop including gschemas.compiled and icon-theme.cache.
  virt-manager.spec
* Fri Dec 25 2015 bruno@ioda-net.ch
- Update to 1.3.2 upstream bugfix release
  virt-manager-1.3.2.tar.bz2
  * Fix dependency issues with vte (bz #1290262)
- Dropped
  virt-manager-1.3.0.tar.bz2
-Fix boo#959049
  Namespace Vte not available for version 2.91
* Sun Dec 13 2015 bruno@ioda-net.ch
- Update to 1.3.1 release upstream bugfix
  virt-manager-1.3.1.tar.bz2
  * Fix command line API on RHEL7 pygobject
- Dropped
  virt-manager-1.3.0.tar.bz2
- Fix boo#958094
  Error starting Virtual Machine Manager: new_sync() takes exactly
  7 arguments (6 given)
- redone patch 104 virtman-load-stored-uris.patch
* Wed Nov 25 2015 carnold@suse.com
- Update to virt-manager 1.3.0
  virt-manager-1.3.0.tar.bz2
  * Git hosting moved to http://github.com/virt-manager/virt-manager
  * Switch translation infrastructure from transifex to fedora.zanata.org
  * Add dogtail UI tests and infrastructure
  * Improved support for s390x kvm (Kevin Zhao)
  * virt-install and virt-manager now remove created disk images if VM install startup fails
  * Replace urlgrabber usage with requests and urllib2
  * virt-install: add –network virtualport support for openvswitch (Daniel P. Berrange)
  * virt-install: support multiple –security labels
  * virt-install: support –features kvm_hidden=on|off (Pavel Hrdina)
  * virt-install: add –features pmu=on|off
  * virt-install: add –features pvspinlock=on|off (Abhijeet Kasurde)
  * virt-install: add –events on_lockfailure=on|off (Abhijeet Kasurde)
  * virt-install: add –network link_state=up|down
  * virt-install: add –vcpu placement=static|auto
- Dropped
  virt-manager-1.2.1.tar.bz2
  34db1af7-fix-adding-iscsi-pools.patch
  360fe110-add-s390x-arch-support.patch
  4970615f-fix-qemu-vs-lxc-detection.patch
  590f5a52-urlfetcher-Clear-cached-ftp-connection-on-cleanupLoc.patch
  5e68b0fc-dont-try-to-set-vmport-on-non-x86.patch
  601a82cb-fix-console_type-if-xen.patch
  76bad650-fix-virt-xml-define-and-update.patch
  77423e7a-connection-catch-more-errors-in-filter_nodedevs.patch
  8dbe96fc-add-s390x-arch-support.patch
  a9b303fb-fix-copy-host-cpu-definition.patch
  aebebbf8-report-an-error-for-pxe-install-without-network.patch
  cde2f0ef-Suppress-gi-warnings-about-lack-of-require_version.patch
  eb92178e-virtinst-fix-storage-pool-lookup.patch
  f30975c3-drop-cow-support.patch
  f81358b0-dont-display-error-if-machine-is-missing-in-XML.patch
  fc93e154-fix-udp-tcp-host-vs-mode-UI.patch
  virtman-autoyast-support.patch
  virtman-supported-disk-formats.patch
* Tue Nov 17 2015 carnold@suse.com
- bsc#955401 - Can't create VM without disk: "list index out of
  range"
  virtinst-set-cache-mode-unsafe-for-install.patch
* Tue Nov 10 2015 carnold@suse.com
- bsc#947129 - Error launching manager: 'URI' is not in list
  Set the locale to avoid parsing errors
  virtman-show-suse-install-repos.patch
* Tue Oct 27 2015 carnold@suse.com
- fate#319659 - vm-install: remove shutcut in virt-manager
  Drop virtman-vminstall.patch
* Tue Oct 27 2015 carnold@suse.com
- bsc#Bug 952241 - virt-manager: LibvirtGLib was imported without
  specifying a version first.
  cde2f0ef-Suppress-gi-warnings-about-lack-of-require_version.patch
* Thu Oct  8 2015 carnold@suse.com
- bsc#949566 - virt-manager: Doesn't detect openSUSE 42 correctly
  virtinst-pvgrub2-bootloader.patch
* Fri Sep 25 2015 carnold@suse.com
- bsc#947288 - qemu-img doesn't support anymore creating cow format
  image
  f30975c3-drop-cow-support.patch
* Wed Sep 23 2015 carnold@suse.com
- bsc#947129 - Error launching manager: 'URI' is not in list
  virtman-show-suse-install-repos.patch
* Tue Sep 22 2015 carnold@suse.com
- bsc#919420 - virt-manager: installation of vm on pp64le: Couldn't
  find hvm kernel for SUSE tree.
  virtinst-add-ppc64-arch-support.patch
- Upstream bug fix to console if running on Xen
  601a82cb-fix-console_type-if-xen.patch
* Wed Sep 16 2015 carnold@suse.com
- bsc#945832 - virt-manager is missing a dependency on
  typelib-1_0-LibvirtGLib-1_0
  virt-manager.spec
- Detect opensuse42 and use grub.xen
  virtinst-pvgrub2-bootloader.patch
* Mon Sep 14 2015 cyliu@suse.com
- bsc#944670: virt-install does not work on SLES 12 SP1 beta3 xen
  590f5a52-urlfetcher-Clear-cached-ftp-connection-on-cleanupLoc.patch
* Fri Sep 11 2015 carnold@suse.com
- Add upstream s390x support patch (bnc#869024)
  360fe110-add-s390x-arch-support.patch
  virtinst-add-ppc64-arch-support.patch
  Drop virtinst-add-s390x-ppc64-arch-support.patch
* Thu Sep 10 2015 carnold@suse.com
- Add upstream s390x support patch (bnc#869024)
  8dbe96fc-add-s390x-arch-support.patch
  virtinst-add-s390x-ppc64-arch-support.patch
  virtinst-s390x-disable-graphics.patch
  Drop virtman-add-s390x-arch-support.patch
  Drop virtman-s390x-default-to-vminstall.patch
* Tue Sep  8 2015 carnold@suse.com
- bsc#942796 - Virtualization/virt-manager: Missing dependeny
  virt-manager.spec
* Thu Sep  3 2015 carnold@suse.com
- bsc#944374 - virt-manager uninstallable on aarch64
  virt-manager.spec
- Add upstream bug fix
  5e68b0fc-dont-try-to-set-vmport-on-non-x86.patch
- Drop virtinst-detect-windows-media.patch as this is not needed
  now that we use libosinfo
* Mon Aug 31 2015 carnold@suse.com
- Drop virtinst-fix-storage-pool-lookup.patch in favor of upstream
  version (bsc#941464).
  eb92178e-virtinst-fix-storage-pool-lookup.patch
* Wed Aug 26 2015 carnold@suse.com
- bsc#942625 - "ERROR:root:Could not find any typelib for
  Libosinfo" during virt-install script to auto-install guest
  virt-manager.spec
* Wed Aug 12 2015 carnold@suse.com
- bsc#941464 - virt-convert attempts to create storage pool images
  even if it already exists
  virtinst-fix-storage-pool-lookup.patch
* Mon Aug 10 2015 carnold@suse.com
- Drop the following patches for bsc#938942 as they are not needed.
  virtman-reset-image-filename-based-on-format.patch
  virtman-allow-other-disk-formats.patch
- Upstream bug fixes
  a9b303fb-fix-copy-host-cpu-definition.patch
  f81358b0-dont-display-error-if-machine-is-missing-in-XML.patch
  aebebbf8-report-an-error-for-pxe-install-without-network.patch
  4970615f-fix-qemu-vs-lxc-detection.patch
* Thu Jul 23 2015 carnold@suse.com
- bsc#938942 - Can't create a vmguest with raw format image with
  virt-manager at first installation (option disable)
  virtman-reset-image-filename-based-on-format.patch
  virtman-allow-other-disk-formats.patch
* Wed Jul  8 2015 carnold@suse.com
- bsc#937336 - ImportError using virt-install
  virt-manager.spec
- Upstream bug fixes
  76bad650-fix-virt-xml-define-and-update.patch
  fc93e154-fix-udp-tcp-host-vs-mode-UI.patch
  34db1af7-fix-adding-iscsi-pools.patch
  77423e7a-connection-catch-more-errors-in-filter_nodedevs.patch
* Wed Jul  8 2015 carnold@suse.com
- bsc#937386 - virt-manager can not create new VMs: "Error
  launching manager: list index out of range"
  virtman-show-suse-install-repos.patch
* Wed Jul  8 2015 cyliu@suse.com
- bnc#910929 - Unable to clone a qcow2 guest
* Mon Jun 15 2015 lma@suse.com
- bnc#934270 - virt-convert cannot handle .ova files
  virtinst-replace-unar-with-other-archivers.patch
* Mon Jun  8 2015 carnold@suse.com
- fate#318394: Update to version 1.2.1
  virt-manager-1.2.1.tar.bz2
  * Bugfix release
  * Fix connecting to older libvirt versions (Michał Kępień)
  * Fix connecting to VM console with non-IP hostname (Giuseppe Scrivano)
  * Fix addhardware/create wizard errors when a nodedev disappears
  * Fix adding a second cdrom via customize dialog
- Dropped tarball and patches
  virt-manager-1.2.0.tar.bz2
  848123e6-fix-memory-stats-for-shutoff-VM.patch
  ebcb7c06-fix-exception-when-the-address-is-not-an-IP.patch
  c4d26d16-fix-VM-polling-on-old-libvirt.patch
  ac2be796-do-not-throw-exception-if-volume-or-pool-dont-exist.patch
  88e18c86-fix-sending-net-removed-signal.patch
  fbdf574c-fix-shortcut-key-for-USB-redir-dev-type.patch
  2c1e482b-fix--show-host-summary-error-windows-flooding.patch
  4b5c836a-read-start-mode-from-inactive-conf-XML.patch
  776c1d97-fix-changing-USB-device-model.patch
  bbc4f83b-enable-qemu_ga-for-sles-11-sp4-and-newer.patch
  f8af2e6b-verify-HYPER-V-support-after-customization.patch
  9ea3fcd1-add-classes-for-SUSE-distros.patch
  23f262ec-fetch-URL-media-from-content-file-for-suse-distros.patch
  5618fa4c-add-support-for-detecting-os-variants-of-suse-distros.patch
  9b99eff7-add-opensuse-13.x-tests.patch
  f5a13510-clone-dont-use-separator-when-disk-under-root.patch
* Fri Jun  5 2015 carnold@suse.com
- Upstream support for suse distros
  9ea3fcd1-add-classes-for-SUSE-distros.patch
  23f262ec-fetch-URL-media-from-content-file-for-suse-distros.patch
  5618fa4c-add-support-for-detecting-os-variants-of-suse-distros.patch
  9b99eff7-add-opensuse-13.x-tests.patch
- Drop virtinst-detect-suse-distros.patch
- Add detection for Open Enterprise Server
  virtinst-detect-oes-distros.patch
- Upstream bug fix
  f5a13510-clone-dont-use-separator-when-disk-under-root.patch
* Tue Jun  2 2015 carnold@suse.com
- bsc#933242 - virt-manager: summary=Error launching manager: list
  index out of range
  virtman-show-suse-install-repos.patch
- Add depedency on typelib(Libosinfo)
* Wed May 20 2015 carnold@suse.com
- Upstream bug fixes
  776c1d97-fix-changing-USB-device-model.patch
  bbc4f83b-enable-qemu_ga-for-sles-11-sp4-and-newer.patch
  f8af2e6b-verify-HYPER-V-support-after-customization.patch
* Fri May 15 2015 carnold@suse.com
- Upstream bug fixes
  fbdf574c-fix-shortcut-key-for-USB-redir-dev-type.patch
  2c1e482b-fix--show-host-summary-error-windows-flooding.patch
  4b5c836a-read-start-mode-from-inactive-conf-XML.patch
* Fri May  8 2015 carnold@suse.com
- Upstream bug fixes
  848123e6-fix-memory-stats-for-shutoff-VM.patch
  ebcb7c06-fix-exception-when-the-address-is-not-an-IP.patch
  c4d26d16-fix-VM-polling-on-old-libvirt.patch
  ac2be796-do-not-throw-exception-if-volume-or-pool-dont-exist.patch
  88e18c86-fix-sending-net-removed-signal.patch
* Mon May  4 2015 carnold@suse.com
- Update to virt-manager 1.2.0
  virt-manager-1.2.0.tar.bz2
  virtinst-default-xen-to-qcow2-format.patch
  * OVMF/AAVMF Support (Laszlo Ersek, Giuseppe Scrivano, Cole Robinson)
  * Improved support for AArch64 qemu/kvm
  * virt-install: Support –disk type=network parameters
  * virt-install: Make –disk just work
  * virt-install: Add –disk sgio= option (Giuseppe Scrivano)
  * addhardware: default to an existing bus when adding a new disk (Giuseppe Scrivano)
  * virt-install: Add –input device option
  * virt-manager: Unify storagebrowser and storage details functionality
  * virt-manager: allow setting a custom connection row name
  * virt-install: Support –hostdev scsi passthrough
  * virt-install: Fill in a bunch of –graphics spice options
  * Disable spice image compression for new local VMs
  * virt-manager: big reworking of the migration dialog
- Dropped tarball and patches
  virt-manager-1.1.0.tar.bz2
  65f7017e-createnet-fix.patch
  virt-manager-Gtk-30.patch
  virtman-sync-vm-startup-for-cpu-usage.patch
  virtinst-ignore-error-403-on-directories.patch
  virtman-check-for-empty-network-name.patch
  activate-default-console.patch
  virtinst-ppc64le.patch
  virtinst-supported-disk-formats.patch
  virtinst-support-suse-distros.patch
  virtman-default-lxc-uri.patch
  virtman-stable-os-support.patch
* Sat Apr 11 2015 stefan.bruens@rwth-aachen.de
- Remove bad dependency on gtk-vnc2. It is provided by the Gtk2
  version of GtkVnc, the Gtk3 version provides gtk-vnc.
  The right dependency is picked up by the autorequires.
* Thu Feb 26 2015 schwab@suse.de
- virtman-allow-creating-i686-vm.patch: Allow creating i686 VM on x86_64
  (bsc#919692)
* Wed Feb 25 2015 carnold@suse.com
- Revert the last commit
* Tue Feb 24 2015 schwab@suse.de
- virtman-allow-creating-i686-vm.patch: Allow creating i686 VM on x86_64
* Fri Jan 23 2015 cbosdonnat@suse.com
- bsc#909602 - virt-manager doesn't show text console for container
  when started from details page.
  activate-default-console.patch.
* Fri Jan 16 2015 carnold@suse.com
- bnc#909348 - Can't create virtual NAT network - interface name
  `net_wlp16s0_00_1f_3b_59_61_3d' must be shorter than IFNAMSIZ
  65f7017e-createnet-fix.patch
* Wed Dec 10 2014 carnold@suse.com
- bnc#909225 - pygrub Unable to find partition containing kernel
  Update virtinst-pvgrub2-bootloader.patch
* Tue Dec  9 2014 carnold@suse.com
- Reorder virt-manager patches according to type
- Drop virtman-cdrom.patch
* Tue Dec  2 2014 carnold@suse.com
- bnc#907958 - virt-manager --debug with no screen SIGABRT
  virtman-check-for-valid-display.patch
* Mon Dec  1 2014 carnold@suse.com
- bnc#907324 - libvirt: unsupported configuration: native I/O needs
  either no disk cache or directsync cache mode, QEMU will fallback
  to aio=threads
  virtinst-set-cache-mode-unsafe-for-install.patch updated
- bnc#907319 - virt-manager: Unable to complete install: 'local
  variable 'distro_distro' referenced before assignment
  virtinst-detect-suse-distros.patch updated
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post scripts
* Wed Oct 22 2014 carnold@suse.com
- Update to virt-manager 1.1.0
  virt-manager-1.1.0.tar.bz2
  * Switch to libosinfo as OS metadata database (Giuseppe Scrivano)
  * Use libosinfo for OS detection from CDROM media labels (Giuseppe Scrivano)
  * Use libosinfo for improved OS defaults, like recommended disk size (Giuseppe Scrivano)
  * virt-image tool has been removed, as previously announced
  * Enable Hyper-V enlightenments for Windows VMs
  * Revert virtio-console default, back to plain serial console
  * Experimental q35 option in new VM ‘customize’ dialog
  * UI for virtual network QoS settings (Giuseppe Scrivano)
  * virt-install: –disk discard= support (Jim Minter)
  * addhardware: Add spiceport UI (Marc-André Lureau)
  * virt-install: –events on_poweroff etc. support (Chen Hanxiao)
  * cli –network portgroup= support and UI support
  * cli –boot initargs= and UI support
  * addhardware: allow setting controller model (Chen Hanxiao)
  * virt-install: support setting hugepage options (Chen Hanxiao)
- Drop upstream patches and old tarball
  virt-manager-1.0.1.tar.bz2
  5332ee4d-enable-media-detection-for-ISO-images.patch
  53341e7e-hide-hardware-removal-for-non-devices.patch
  53342f31-set-right-ip-address-for-ipv6.patch
  53375bad-raise-value-error-when-no-ipaddr-set.patch
  53388de2-show-port-number-for-active-autoport-VM.patch
  53397ae0-check-ip-address-format.patch
  53399b45-hook-into-domain-balloon-event.patch
  533d708d-fix-showing-vcpus-values.patch
  533d7602-fix-changing-graphics-type.patch
  533d7be7-clarify-iscsi-IQN-fields.patch
  5345682c-addstorage-remove-whitespace-for-storage-path.patch
  534bcfa0-use-uniformed-expression-of-Default.patch
  534be092-early-detect-ftp-connection-errors.patch
  534d45db-hiding-removebutton-for-USB-controller.patch
  534d6406-display-the-domain-for-PCI-devices.patch
  534eafe4-avoid-useless-errors-when-connection-closes.patch
  5350d9cc-display-error-on-empty-installation-URL.patch
  535584ed-fix-target-validation-when-editing-device.patch
  535fb6f6-hide-scrollbar-until-something-scrollable.patch
  535fe0c2-fix-screenshot-with-qxl-spice.patch
  535feaca-fix-storage-when-directory-name-contains-whitespace.patch
  535ff0b7-fix-install-when-one-package-is-already-installed.patch
  536152fe-fix-error-detecting-OS-in-show-all-list.patch
  536154d8-show-error-if-launching-delete-dialog-fails.patch
  53615662-call-path_exists-before-getting-storage-volume.patch
  536677aa-better-handling-of-keyboard-input-type.patch
  5385d602-lxc-no-default-disk.patch
  53869170-virt-install-add-events-support.patch
  538a11dc-raise-error-if-populating-summary-page-fails.patch
  538a3609-virtconv-fix-use-of-relative-OVF-file.patch
  538a3ba9-diskbackend-start-pool-if-not-running.patch
  538a6862-vnc-dont-force-keyboard-grab-before-widget-is-realized.patch
  538ca3f3-use-correct-dictionary-keys-for-old-pool-net-polling.patch
  538d00a4-xen-keyboard-cant-be-removed.patch
  538e2f74-fix-pool-create-call.patch
  538edb3b-manpage-fix-incorrect-description.patch
  5397b647-createnet-enable-specifying-29-subnet.patch
  539e8cca-createpool-fix-creation-of-gluster-pools.patch
  53a05e73-fix-edit-maxvcpus.patch
  53a995cb-fix-usb-storage-removable-syntax.patch
  53ac1f8d-createnet-validate-last-page-before-creating-network.patch
  53ac1f8d-fix-show_err-typo.patch
  53ad17e6-createnet-fix-a-small-pylint.patch
  53b39a13-dont-create-disk-images-world-readable-executable.patch
  53b409bc-add-keep-alive-method-and-connection-check.patch
  53b409bd-console-prevent-access-to-deleted-objects.patch
  53b728c6-connection-handle-unsupported-KeepAlive.patch
  53b728c6-report-error-during-connection-bring-up.patch
  53bb1995-network-refresh-XML-definition-on-state-update.patch
  53ce11d1-honor-untoggled-set-fixed-MAC-address.patch
- Dropped xend based virtman-autorestart.patch
* Mon Oct 20 2014 dimstar@opensuse.org
- Add virt-manager-Gtk-30.patch: Specify in the code that we expect
  Gtk 3.0 typelibs. The sumbold typelib(Gtk), as auto-detected by
  go-find-deps, is provided by Gtk2 and Gtk3. As we also pull in
  Vte, though, we are certain that we DO require the Gtk 3.0
  variant (boo#901869).
* Fri Oct 10 2014 cbosdonnat@suse.com
- bnc#900320 - virt-install properly finds the lxc emulator when
  xen-tools is installed
* Thu Oct  9 2014 carnold@suse.com
- Remove hardcoded package dependencies in spec file and instead
  use gobject-introspection
  virt-manager.spec
* Mon Sep 29 2014 carnold@suse.com
- bnc#898925 - virt-install errors out while installing SLES12
  using --location
  virtinst-ppc64le.patch
* Fri Sep  5 2014 ro@suse.de
- modify virtinst-ppc64le.patch to call qemu-system-ppc64
  for ppc64 and ppc64le (bnc#894956)
* Thu Aug 28 2014 carnold@suse.com
- bnc#892821 - Minor enhancement to virt-manager's operating system
  detection
  virtinst-ignore-error-403-on-directories.patch (Leonardo Chiquitto)
* Tue Aug 26 2014 carnold@suse.com
- bnc#886311 - Xen Virtual Machine Manager does not display CPU
  usage stats
- bnc#888289 - After domU shutdown, sometimes virt-manager doesn't
  refresh the domU status.
  virtman-sync-vm-startup-for-cpu-usage.patch
* Wed Aug 20 2014 ro@suse.de
- add patch: virtinst-ppc64le.patch
  initial ppc64le support for virt-install
* Mon Aug 18 2014 carnold@suse.com
- bnc#875111 - When kvm guest is in crashed state, virt-manager
  reports guest as still running, no option to shutdown/destroy
  virtman-allow-destroy-from-shutdown-menu-of-crashed-vm.patch
- bnc#892003 - create virtual machine with Virt Manager randomly
  times out with large memory guest
  virtman-increase-setKeepAlive-count.patch
* Mon Aug 11 2014 carnold@suse.com
- bnc#888173 - KVM: Unable to install: no console output from
  virt-install
  virtman-s390x-default-to-vminstall.patch
* Tue Aug  5 2014 cyliu@suse.com
- bnc#890350 - Can't create virtual networks through virt-manager
  53ad17e6-createnet-fix-a-small-pylint.patch
* Fri Jul 25 2014 carnold@suse.com
- Upstream bug fix
  53ce11d1-honor-untoggled-set-fixed-MAC-address.patch
* Tue Jul 22 2014 carnold@suse.com
- bnc#888251 - sles 12 Xen PV guest fails to install using network
  NFS install method
  virtinst-nfs-install-sanitize.patch
* Tue Jul 22 2014 carnold@suse.com
- bnc#887868 - libvirt: shouldn't detect pool's status while
  connecting to hypervisor
  virtinst-refresh_before_fetch_pool.patch (Chun Yan Liu)
* Mon Jul 21 2014 carnold@suse.com
- bnc#888173 - KVM: Unable to install: no console output from
  virt-install
  virtman-add-s390x-arch-support.patch
* Thu Jul 17 2014 carnold@suse.com
- bnc#885308 - pass virtio-rng-pci to the guest qemu
  virtinst-add-default-rng-device.patch
* Wed Jul  9 2014 carnold@suse.com
- Fix GUI failure to display addition of a second disk
  Dropped virtman-device-flags.patch
* Wed Jul  9 2014 carnold@suse.com
- bnc#885380 - virt-install: by default generates raw format
  against various virtual disk formats
  virtinst-supported-disk-formats.patch
  virtman-supported-disk-formats.patch
- Dropped virtinst-qed.patch, virtman-qed.patch
* Tue Jul  8 2014 carnold@suse.com
- bnc#869026 - Build0198: Unable to complete install: 'XML error:
  No PCI buses available'
  virtman-add-s390x-arch-support.patch
- Upstream bug fixes
  53ac1f8d-createnet-validate-last-page-before-creating-network.patch
  53ac1f8d-fix-show_err-typo.patch
  53b39a13-dont-create-disk-images-world-readable-executable.patch
  53b409bc-add-keep-alive-method-and-connection-check.patch
  53b409bd-console-prevent-access-to-deleted-objects.patch
  53b728c6-report-error-during-connection-bring-up.patch
  53b728c6-connection-handle-unsupported-KeepAlive.patch
  53bb1995-network-refresh-XML-definition-on-state-update.patch
* Tue Jul  1 2014 carnold@suse.com
- bnc#885094 - sles 12 beta 9 virt manager install of sles 12 pv
  guest over nfs fails to reboot
  virtman-dont-allow-grub.xen-to-be-deleted.patch
- bnc#885273 - create virtual network wizard accept empty name
  virtman-check-for-empty-network-name.patch
* Fri Jun 27 2014 carnold@suse.com
- Upstream bug fixes
  53ac1f8d-fix-show_err-typo.patch
  53ac1f8d-createnet-validate-last-page-before-creating-network.patch
- KVM: Don't check for /dev/kvm. It is now built into the kernel
  virtman-kvm.patch
* Tue Jun 24 2014 carnold@suse.com
- Upstream bug fix
  53a995cb-fix-usb-storage-removable-syntax.patch
* Tue Jun 17 2014 carnold@suse.com
- Upstream bug fixes
  5397b647-createnet-enable-specifying-29-subnet.patch
  539e8cca-createpool-fix-creation-of-gluster-pools.patch
  53a05e73-fix-edit-maxvcpus.patch
* Fri Jun  6 2014 carnold@suse.com
- bnc#881551 - virt-manage: default storage image called
  opensuse13.img for SLE-Server
  virtinst-detect-suse-distros.patch
* Thu Jun  5 2014 carnold@suse.com
- bnc#881549 - virt-manager/xen: Error changing VM configuration:
  'NoneType' object has no attribute 'split'
  virtinst-xenbus-disk-index-fix.patch
* Wed Jun  4 2014 carnold@suse.com
- Upstream bug fix
  538edb3b-manpage-fix-incorrect-description.patch
* Tue Jun  3 2014 carnold@suse.com
- Upstream bug fixes
  536677aa-better-handling-of-keyboard-input-type.patch
  5385d602-lxc-no-default-disk.patch
  53869170-virt-install-add-events-support.patch
  538a11dc-raise-error-if-populating-summary-page-fails.patch
  538a3609-virtconv-fix-use-of-relative-OVF-file.patch
  538a3ba9-diskbackend-start-pool-if-not-running.patch
  538ca3f3-use-correct-dictionary-keys-for-old-pool-net-polling.patch
  538d00a4-xen-keyboard-cant-be-removed.patch
  538e2f74-fix-pool-create-call.patch
- Dropped 531e0a82-reverse-keyboard-grab-commit.patch. Fixed instead
  with this patch.
  538a6862-vnc-dont-force-keyboard-grab-before-widget-is-realized.patch
* Thu May 29 2014 carnold@suse.com
- Set cache mode for target installation disk to unsafe for better
  performance
  virtinst-set-cache-mode-unsafe-for-install.patch
- Renamed virtman-lxc-no-default-disk.patch to an upstream timestamp
  name 5385d602-lxc-no-default-disk.patch
* Tue May 27 2014 cbosdonnat@suse.com
- bnc#870587 - Don't create a default QEMU disk image in the new lxc
  container wizard.
  virtman-lxc-no-default-disk.patch
* Wed May 21 2014 cbosdonnat@suse.com
- Improve virt-manager default connections at first start
  * virtman-default-lxc-uri.patch: when only libvirt's lxc driver
    is available locally, add lxc:///
  * virtman-add-connect-default.patch: when no hypervisor can be
    found locally, open the new connection dialog
* Thu May 15 2014 carnold@suse.com
- bnc#874594 - virt-manager allows issuing of start for xen domain
  twice, resulting in failure
  virtman-prevent-double-click-starting-vm-twice.patch
* Thu May 15 2014 carnold@suse.com
- bnc#877907 - when starting guest in virt--manager with details
  pane open, keyboard is grabbed erroneously
  531e0a82-reverse-keyboard-grab-commit.patch
* Thu May  1 2014 carnold@suse.com
- Dropped patch as libvirt has fix for issue
  virtman-shutdown-with-acpi-button.patch
* Wed Apr 30 2014 carnold@suse.com
- Upstream bug fixes
  535fb6f6-hide-scrollbar-until-something-scrollable.patch
  535fe0c2-fix-screenshot-with-qxl-spice.patch
  535feaca-fix-storage-when-directory-name-contains-whitespace.patch
  535ff0b7-fix-install-when-one-package-is-already-installed.patch
  536152fe-fix-error-detecting-OS-in-show-all-list.patch
  536154d8-show-error-if-launching-delete-dialog-fails.patch
  53615662-call-path_exists-before-getting-storage-volume.patch
* Tue Apr 29 2014 carnold@suse.com
- s390x: Set the correct emulator
  virtinst-set-qemu-emulator.patch
* Mon Apr 28 2014 carnold@suse.com
- Content file on media changed again. Update suse detection code.
  virtinst-detect-suse-distros.patch
* Thu Apr 24 2014 carnold@suse.com
- bnc#874772 - virt-manager: Unable to complete install: 'xmlDesc
  in virDomainCreateXML must not be NULL'
  virtinst-pvgrub2-bootloader.patch
- KVM: Use /usr/bin/qemu-system-x86_64 as the default emulator
  virtinst-set-qemu-emulator.patch
* Tue Apr 22 2014 carnold@suse.com
- Upstream bug fix
  535584ed-fix-target-validation-when-editing-device.patch
* Mon Apr 21 2014 carnold@suse.com
- bnc#874408 - virt-manager and libvirt issues persist - unable to
  create or launch
  virtman-vminstall.patch
* Fri Apr 18 2014 carnold@suse.com
- Upstream bug fix
  5350d9cc-display-error-on-empty-installation-URL.patch
* Thu Apr 17 2014 carnold@suse.com
- Dropped unused and unnecessary patches
  virtinst-cdrom.patch
  virtman-update-backend.patch
  virtman-slow-mouse.patch
  virtman-reverse-serialcon.patch
- Reordered some patches
* Wed Apr 16 2014 carnold@suse.com
- Upstream bug fixes
  534bcfa0-use-uniformed-expression-of-Default.patch
  534be092-early-detect-ftp-connection-errors.patch
  534d45db-hiding-removebutton-for-USB-controller.patch
  534d6406-display-the-domain-for-PCI-devices.patch
  534eafe4-avoid-useless-errors-when-connection-closes.patch
* Mon Apr 14 2014 carnold@suse.com
- bnc#872789 - XEN domain fails to start when xen disk is atttached
  virtinst-xenbus-disk-index-fix.patch
- bnc#872777 - virt-manager - Error shutting down domain: internal
  error: Failed to shutdown domain '3' with libxenlight
  virtman-shutdown-with-acpi-button.patch
* Wed Apr  9 2014 carnold@suse.com
- Upstream bug fix
  5345682c-addstorage-remove-whitespace-for-storage-path.patch
- Add minimal detection for windows media
  virtinst-detect-windows-media.patch
* Tue Apr  8 2014 carnold@suse.com
- bnc#872543 - virt-manager: unable to install i386 SLES
  virtinst-detect-suse-distros.patch
- bnc#872517 - Error starting domain: internal error: libxenlight
  failed to create new domain '2k12r2'
  Dropping virtinst-keep-cdrom-media-attached.patch for libvirt fix
* Thu Apr  3 2014 carnold@suse.com
- Upstream bug fixes
  533d708d-fix-showing-vcpus-values.patch
  533d7602-fix-changing-graphics-type.patch
  533d7be7-clarify-iscsi-IQN-fields.patch
- Dropped virtman-init-vm-processor-topology.patch in favor of
  upstream 533d708d-fix-showing-vcpus-values.patch
* Wed Apr  2 2014 carnold@suse.com
- bnc#869024 - Build0198: Only option to create a virtual machine is
  "import existing disk image"
  virtman-add-s390x-arch-support.patch
* Wed Apr  2 2014 carnold@suse.com
- bnc#871642 - virt-manager wants to install libvirt-daemon-xen
  even when it is installed
  xen.spec
- Xen: Virt-install won't reboot VM after install of SLE HVM guest
  because of libxl exception.
  virtinst-keep-cdrom-media-attached.patch
* Wed Apr  2 2014 cyliu@suse.com
- Fate#315125: add NOCOW flag
  virtinst-vol-default-nocow.patch
* Mon Mar 31 2014 carnold@suse.com
- Upstream bug fixes
  53375bad-raise-value-error-when-no-ipaddr-set.patch
  53388de2-show-port-number-for-active-autoport-VM.patch
  53397ae0-check-ip-address-format.patch
  53399b45-hook-into-domain-balloon-event.patch
* Fri Mar 28 2014 carnold@suse.com
- Reverse the last commit on requires for grub2-x86_64-xen.  This
  dependency will live in the xen-tools RPM because it is a xen
  specific requirement.
  virt-manager.spec
* Fri Mar 28 2014 carnold@suse.com
- Requires for grub2-x86_64-xen is only valid for x86_64
  virt-manager.spec
* Thu Mar 27 2014 carnold@suse.com
- Virt-install is using the old legacy qemu as an emulator
  virtinst-set-qemu-emulator.patch
* Thu Mar 27 2014 carnold@suse.com
- Upstream bug fixes
  5332ee4d-enable-media-detection-for-ISO-images.patch
  53341e7e-hide-hardware-removal-for-non-devices.patch
  53342f31-set-right-ip-address-for-ipv6.patch
* Wed Mar 26 2014 carnold@suse.com
- bnc#870098 - virt-manager+x show wrong number of assigned cpu's
  virtman-init-vm-processor-topology.patch
* Mon Mar 24 2014 carnold@suse.com
- Make Requires of grub2-x86_64-xen conditional
* Sat Mar 22 2014 carnold@suse.com
- Update to virt-manager version 1.0.1
  virt-manager-1.0.1.tar.bz2
  * virt-install/virt-xml: New --memorybacking option (Chen Hanxiao)
  * virt-install/virt-xml: New --memtune option (Chen Hanxiao)
  * virt-manager: UI for LXC <idmap> (Chen Hanxiao)
  * virt-manager: gsettings key to disable keygrab (Kjö Hansi Glaz)
  * virt-manager: Show domain state reason in the UI (Giuseppe Scrivano)
  * Fix a number of bugs found since the 1.0.0 release
- Dropped 35 timestamp named patches now contained in new tarball
* Fri Mar 21 2014 carnold@suse.com
- bnc#869165 - virt-manager: add connection - missing avahi
  virt-manager.spec
- bnc#863821 - Xen unable to boot paravirtualized VMs installed
  with btrfs
  virtinst-pvgrub2-bootloader.patch
- Switch out redhat defaults for suse defaults
  virtman-stable-os-support.patch
* Wed Mar 19 2014 carnold@suse.com
- bnc#868194 - virt-manager gets stuck with some netinst urls
  532a3213-pass-correct-connection-to-install.patch
  532a3213-fix-url-autodetect-timeout.patch
  532a3213-exit-URL-detection-immediately-if-detection-fails.patch
- bnc#869208 - virt-manager create new virtual machine fail
  virtman-show-suse-install-repos.patch
- bnc#869181 - virt-manager: vm wizard -Error launching manager:
  'NoneType' object has no attribute 'startswith'
  virtinst-modify-gui-defaults.patch
* Tue Mar 18 2014 carnold@suse.com
- bnc#868676 - Error changing VM configuration: unsupported
  configuration: unknown driver format value 'block'
  virtinst-xen-drive-type.patch
* Tue Mar 18 2014 carnold@suse.com
- bnc#868200 - Unable to complete install: "NoneType' object has no
  attribute '__getitem__"
  virtinst-detect-suse-distros.patch
* Fri Mar 14 2014 carnold@suse.com
- For Xen always have the arch expander expanded.
- For Xen and KVM default to Network install if host was installed
  from the network
- Default to a bridge with an actual inet address if available
  virtinst-modify-gui-defaults.patch
- We are not supporting PV ISO installs with virt-install.
  Drop the following patches
  virtinst-allow-pv-iso-install.patch
  virtman-allow-pv-iso-install.patch
* Fri Mar 14 2014 carnold@suse.com
- Upstream bug fixes
  5321d3cd-virtinst-drop-cpu_map-parsing-of-arch-features.patch
  5321d3d0-virtinst-drop-parsing-of-cpu-features.patch
  5321f256-virtinst-use-libvirt-getCPUModelNames.patch
  532255b4-unselect_all-members-before-clear-model.patch
* Thu Mar 13 2014 carnold@suse.com
- Fix start_libvirtd to correctly use systemd to start libvirtd
  virtman-libvirtd-not-running.patch
- Upstream bug fixes
  531dd0ca-lxc-define-private-network.patch
  53207f40-invalidate-cached-caps.patch
  5320c976-fix-adding-empty-cdrom-floppy-drive.patch
* Tue Mar 11 2014 carnold@suse.com
- bnc#867796 - virt-manager New Virtual Machine "Vm-install"
  virtman-vminstall.patch
* Tue Mar 11 2014 carnold@suse.com
- bnc#867749 - virt-manager polling connection
  virtman-load-stored-uris.patch
- bnc#866287 - virt-manager suggests to install
  "qemu / libvirt-daemon-qemu / libvirt-daemon-driver-network" at startup
  virtman-packages.patch
- Use qemu-system-x86_64 instead of the deprecated qemu-kvm
  virtman-kvm.patch
* Mon Mar 10 2014 carnold@suse.com
- Upstream bug fixes
  531db6a7-new-volume-tooltip-logic.patch
  531dbfa7-handle-errors-when-deregistering-events-on-close.patch
* Fri Mar  7 2014 carnold@suse.com
- Upstream bug fixes
  5318a2cd-cpu-model-fallback-failure-fix.patch
  5318a626-adding-filesystem-device-fix.patch
  5318aa88-invalid-libvirt-volume-XML.patch
  5318b486-virtinstall-location-iso-fix.patch
  5319db07-customize-add-disk-fix.patch
* Thu Mar  6 2014 carnold@suse.com
- Allow the installation repos provided by zypper to be selected
  as network installation sources
  virtman-show-suse-install-repos.patch
* Mon Mar  3 2014 carnold@suse.com
- Upstream bug fixes
  530f80f5-handle-missing-storage-volumes.patch
  5310bd89-console-fix-unsetting-resize-guest.patch
  5310e3ac-set-show_arrow-to-true.patch
  5310e3ac-vmmConsolePages-toggle-visibilities-on-page-change.patch
  5310e3ac-vmmDetails-toggle-visibilities-on-page-change.patch
  5310e52d-fix-setting-default-window-size.patch
* Thu Feb 27 2014 carnold@suse.com
- Upstream bug fixes
  53022930-lxc-connection-fix.patch
  530229cb-non-x86-kvm-creation-fix.patch
  53023f56-dont-alter-caps-machine-list-on-create.patch
  53030858-generate_target-fix.patch
  53037798-not-customizing-generate_target-fix.patch
  53047532-dont-get-duplicated-disks.patch
  53047595-calculate-disk-bus-properly.patch
  530987c4-disk-bus-calculation-fix.patch
  530c021c-attempt-empty-path-on-virDomainBlockStats.patch
  530cd6ab-log-broken-xml.patch
  530cf4de-allow-numbered-object-names.patch
  530cfa5e-close-connection-on-tick-failure-fix.patch
* Wed Feb 26 2014 cbosdonnat@suse.com
- virt-manager-common requires python-libxml2
* Fri Feb 14 2014 carnold@suse.com
- If connection is Xen, default to PV instead of HVM.
  virtman-default-to-xen-pv.patch
* Thu Feb 13 2014 carnold@suse.com
- Update to virt-manager 1.0.0
  * virt-manager: Snapshot support
  * New tool virt-xml: Edit libvirt XML in one shot from the command line. Check out some examples: http://www.redhat.com/archives/libvir-list/2014-January/msg01226.html
  * Improved defaults: qcow2, USB2, host CPU model, guest agent channel, …
  * Introspect command line options like –disk=? or –network=help
  * The virt-image tool will be removed before the next release, speak up if you have a good reason not to remove it.
  * virt-manager: Support arm vexpress VM creation
  * virt-manager: Add guest memory usage graphs (Thorsten Behrens)
  * virt-manager: UI for editing devices (Cédric Bosdonnat)
  * Spice USB redirection support (Guannan Ren)
  * UI and command line support (Stefan Berger)
  * UI and command line support (Giuseppe Scrivano)
  * UI and command line support (Chen Hanxiao)
  * command line support (Chen Hanxiao)
  * virt-manager: support for glusterfs storage pools (Giuseppe Scrivano)
  * cli: New options –memory, –features, –clock, –metadata, –pm
  * Greatly improve app responsiveness when connecting to remote hosts
  * Lots of UI cleanup and improvements
  virt-manager-1.0.0.tar.bz2
- Dropped the following patches by taking a newer upstream tarball
  virt-manager-0.10.0.tar.bz2
  Add-memory-stats-widget-also-to-manager-tree-view.patch
  Attempt-empty-path-on-virDomainBlockStats.patch
  Base-mem-statistics-on-virDomainMemoryStats-if-avail.patch
  virtinst-add-cache-modes.patch
  virtinst-allow-ide-hdb.patch
  virtinst-clone-disks.patch
  virtinst-none-arch-fix.patch
  virtman-support-unsafe-migration.patch
* Mon Feb  3 2014 carnold@suse.com
- Fix patch using util.is_error_nosupport (0.10.1) when it should
  be using support.is_error_nosupport (0.10.0)
  added Base-mem-statistics-on-virDomainMemoryStats-if-avail.patch
* Thu Jan 23 2014 tbehrens@suse.com
- Fate#313213: pending upstream patches added
  * added Add-memory-stats-widget-also-to-manager-tree-view.patch
  * added Base-mem-statistics-on-virDomainMemoryStats-if-avail.patch
  * added Attempt-empty-path-on-virDomainBlockStats.patch
* Wed Jan 22 2014 carnold@suse.com
- Add Requires on virt-manager for virt-install
- Add sles12/sled12 as supported distros
* Tue Jan  7 2014 carnold@suse.com
- Translate virt-install.ycp to virt-install.rb
  Added virt-install.rb
  Dropped virt-install.ycp
* Tue Dec 24 2013 carnold@suse.com
- Drop virtman-autoconnect.patch
* Sat Dec 14 2013 ohering@suse.de
- Pass --prefix to setup.py to fix build in 12.2 and older
* Mon Dec  9 2013 carnold@suse.com
- Allow vm-install to be launched from the menu as an independent
  process.
* Mon Dec  9 2013 cbosdonnat@suse.com
- bnc#847641 - L3: block device disappears with disabling cache
  virtman-support-unsafe-migration.patch
* Mon Nov 25 2013 carnold@suse.com
- fate#316388: virt-manager: Support the latest version (0.10.x or newer)
  virt-manager-0.10.0.tar.bz2
- Update to virt-manager 0.10.0 includes
  * Merged code with python-virtinst. virtinst is no longer public
  * Port from GTK2 to GTK3 (Daniel Berrange, Cole Robinson)
  * Port from gconf to gsettings
  * Port from autotools to python distutils
  * Remove virt-manager-tui
  * Remove HAL support
  * IPv6 and static route virtual network support (Gene Czarcinski)
  * virt-install: Add –cpu host-passthrough (Ken ICHIKAWA, Hu Tao)
- Patches now included from the deprecated python-virtinst repo
  virt-install.desktop
  virt-install.ycp
  virtinst-allow-ide-hdb.patch
  virtinst-allow-pv-iso-install.patch
  virtinst-add-cache-modes.patch
  virtinst-cdrom.patch
  virtinst-clone-disks.patch
  virtinst-detect-suse-distros.patch
  virtinst-none-arch-fix.patch
  virtinst-qed.patch
  virtinst-storage-ocfs2.patch
  virtinst-support-suse-distros.patch
  virtinst-xen-drive-type.patch
- Dropped old tarball and upstream fixes
  virt-manager-0.9.5.tar.bz2
  virtman-dropped-connection-segfault.patch
  virtman-graph-row-spacing.patch
  virtman-memleak-callbacks.patch
  virtman-memleak-disable-graph.patch
* Thu Sep  5 2013 carnold@suse.com
- bnc#821214 - virt-manager has a big memory leak.
  virtman-memleak-disable-graph.patch
  virtman-memleak-callbacks.patch
  virtman-graph-row-spacing.patch
* Thu Aug 29 2013 carnold@suse.com
- Fix a segfault when the connection is dropped
  virtman-dropped-connection-segfault.patch
* Thu Jul 25 2013 carnold@suse.com
- Use correct kernel argument for specifying autoyast files.
  Renamed virtman-autoyast-label.patch to
  virtman-autoyast-support.patch
* Tue Jul 23 2013 carnold@suse.com
- Add opensuse 13 as a host default for VM creation
* Mon Jul 22 2013 carnold@suse.com
- Fix kvm installs defaulting to qemu instead of kvm.
  virtman-allow-pv-iso-install.patch
* Wed Jul 17 2013 carnold@suse.com
- Fix exception when selecting ISO for install source.
  virtman-autoyast-label.patch
* Wed Jul  3 2013 carnold@suse.com
- Default to virt-install when installation icon is selected
- Allow virt-install to install Xen PV guests from ISO media
  virtman-allow-pv-iso-install.patch
- Detect SUSE installation sources and use as default when found
  virtman-default-guest-from-host-os.patch
- Use 'Autoyast' instead of 'Kickstart' if installing SUSE distro
  virtman-autoyast-label.patch
* Fri May 31 2013 carnold@suse.com
- Renamed all patches from '.diff' to '.patch'.
* Fri May 31 2013 carnold@suse.com
- bnc#822531 - Virt-manager will reset the domu's 'Autostart'
  option to unselected status as soon as changing the domu's any
  virtual hardware through virt-manager (Xen only)
  virtman-autorestart.diff
* Tue Apr  2 2013 carnold@suse.com
- Update to virt-manager 0.9.5
  * Enable adding virtio-scsi disks (Chen Hanxiao)
  * Support security auto-relabel setting (Martin Kletzander)
  * Support disk iotune settings (David Shane Holden)
  * Support 'reset' as a reboot option (John Doyle)
  * Bug fixes and minor improvements
* Mon Feb 11 2013 carnold@suse.com
- bnc#802778 - virt-manager doesn't start
  Remove virt-manager-tui from the package.  It requires newt_syrup
  which is not part of the distro.
  virt-manager.spec
* Mon Feb  4 2013 carnold@suse.com
- bnc#801988 - virt-manager requires for vtemodule.so wrong on s390x
  virt-manager.spec
* Mon Feb  4 2013 carnold@suse.com
- bnc#801987 - virt-manager is not able to create new VM in qemu
  Updated virtman-vminstall.diff
* Thu Jan 31 2013 carnold@suse.com
- fate#314135: Support PVSCSI on XEN and VirtioSCSI on KVM -
  Implement pass through block device
- fate#313076: HBA passthrough for kvm
  virtman-git-scsi.diff
  virtman-git-scsi-lun.diff
* Wed Jan  2 2013 carnold@novell.com
- Enable virt-manager to be built for s390x
* Thu Sep 20 2012 carnold@novell.com
- bnc#780660 - Yast does not offer "Virtualization" section by
  default, and no "Install Hypervisor" option, after loading
  yast-vm.
  virtman-kvm-packages.diff
* Tue Sep 18 2012 carnold@novell.com
- bnc#780859 - virt-manager doesn't show the console screen
  virtman-reverse-serialcon.patch
* Thu Aug  9 2012 carnold@novell.com
- bnc#772744 - vm-install requires root, while original virt-manager
  vm creation code works fine as user
  This patch makes virt-install available for local installs via a
  pop-down menu.
  virtman-virtinstall.diff
* Tue Aug  7 2012 carnold@novell.com
- Update to virt-manager 0.9.4
  0.9.4 is a bugfix release for 0.9.2, fixing VNC keyboard focus
  issues. 0.9.2 changelog:
  * Convert to gtkbuilder: UI can now be editted with modern glade tool
  * virt-manager no longer runs on RHEL5, but can manage a remote RHEL5 host
  * Option to configure spapr net and disk devices for pseries (Li Zhang)
  * Many bug fixes and improvements
* Fri Jul 13 2012 carnold@novell.com
- Update to virt-manager 0.9.3
  * Convert to gtkbuilder: UI can now be editted with modern glade tool
  * virt-manager no longer runs on RHEL5, but can manage a remote RHEL5 host
  * Option to configure spapr net and disk devices for pseries (Li Zhang)
  * Many bug fixes and improvements
* Mon Jun 25 2012 carnold@novell.com
- bnc#768660 - virt-manager complains about missing SuSEconfig.gtk2
  virt-manager.spec
* Fri Apr 27 2012 reddwarf@opensuse.org
- Recommend python-SpiceClientGtk
* Thu Mar 29 2012 berendt@b1-systems.de
- added missing requirements python-gobject, python-gtk,
  python-gconf and xorg-x11-fonts
* Mon Mar  5 2012 carnold@novell.com
- Previous commit should just be Requires: python-gconf
* Wed Feb 22 2012 carnold@novell.com
- bnc#732617 - virt-manager does not start when python-virtinst is
  installed
* Thu Feb 16 2012 carnold@novell.com
- bnc#745221 - virt-manager should require python-gconf
  Requires: python2-gconf >= 1.99.11-7
* Fri Feb  3 2012 carnold@novell.com
- Remove the virt-install sources from the virt-manager package.
  The virt-install applications are now found in python-virtinst.
* Fri Feb  3 2012 carnold@novell.com
- Update to virt-manager 0.9.1
  * Support for adding usb redirection devices (Marc-André Lureau)
  * Option to switch usb controller to support usb2.0 (Marc-André Lureau)
  * Option to specify machine type for non-x86 guests (Li Zhang)
  * Support for filesystem device type and write policy (Deepak C Shetty)
  * Many bug fixes!
- Update to virtinst 0.600.1
  * virt-install: --redir option for usb redirection (Marc-André Lureau)
  * virt-install: Advanced --controller support for usb2 (Marc-André Lureau)
  * Many bug fixes and minor improvments.
* Thu Jan  5 2012 carnold@novell.com
- Two spec file changes.  Update version of libvirt required.
  Added a Provides on python-virtinst.
* Thu Jan  5 2012 carnold@novell.com
- console: Fix hang when reconnecting to remote VNC console
  virtman-git-reconnect.diff
- KVM: Enable support for SATA bus option
  virtman-git-sata-support.diff
  virtinst-git-sata-support.diff
* Mon Dec  5 2011 carnold@novell.com
- bnc#731218 - Xen guest consoles started from the virt manager
  have slow mouse response in the guest
  virtman-reverse-git-tooltip.patch
* Mon Nov  7 2011 carnold@novell.com
- bnc#727662 - Error polling connection 'qemu:///system' with guest
  init 0
  virtman-update-backend.diff
* Fri Nov  4 2011 carnold@novell.com
- Update to latest upstream git version for various bug fixes
  virtmanager: a712a7b32e6d7b7d9d53561b3ed2078190191560
  virtinst: 15d4901a3c8b855838931976e023158b8cda1c37
* Fri Oct 28 2011 carnold@novell.com
- Upstream bug fixes
  virtinst-git-mac-prefix.diff
  virtman-git-error-reporting.diff
  virtman-git-explicit-python.diff
* Wed Oct 12 2011 carnold@novell.com
- Fix broken define in virtinst-qed.diff
* Wed Oct  5 2011 carnold@novell.com
- Enforce dependency on vm-install version 0.5.6
* Thu Sep 29 2011 carnold@novell.com
- bnc#722524 - [SLES11SP2Beta6] virt-manager fails to change the
  device model for the NICs from default to virtio (kvm)
- bnc#683667 - On KVM, virt-manager incorrectly writed duplicated
  device information into guest's configuration file
  (/etc/libvirt/qemu/DOMNAME.xml)
  virt-manager version 0.9.0
* Tue Sep 27 2011 carnold@novell.com
- Fix broken vminstall patch
  virtman-vminstall.diff
* Wed Sep 21 2011 carnold@novell.com
- KVM: Add missing qed support to virtinst
* Wed Sep 21 2011 carnold@novell.com
- Upstream bug fixes
  virtman-netstats-fix.diff
  virtman-finish-button-fix.diff
  virtman-shutoff-fix.diff
  virtman-set-has-window-fix.diff
  virtman-grep-fix.diff
  virtman-no-cd-present-fix.diff
  virtman-resize-menu-fix.diff
  virtman-vcpu-count-fix.diff
  virtman-storage-pool-fix.diff
  virtman-domain-name-fix.diff
  virtman-unapplied-changes-fix.diff
  virtman-details-fix.diff
  virtman-delete-fix.diff
  virtman-collidelist-fix.diff
  virtman-char-device-mode-fix.diff
  virtinst-hv-version-fix.diff
  virtinst-initrd-inject-fix.diff
  virtinst-initrd-inject2-fix.diff
  virtinst-no-volume-fix.diff
  virtinst-prompts-fix.diff
  virtinst-cpu-model-name-fix.diff
  virtinst-xml-clear-fix.diff
  virtinst-remote-storage-fix.diff
  virtinst-error-message-fix.diff
  virtinst-typo-fix.diff
  virtinst-cdrom.diff
  virtinst-storage-ocfs2.diff
* Tue Sep 20 2011 carnold@novell.com
- bnc#718861 - [SLES11SP2beta5] virt-manager unable to boot
  Windows2008 guest with virtio disk and network device (kvm)
- Update to virt-manager 0.9.0
  * Use a hiding toolbar for fullscreen mode
  * Use libguestfs to show guest packagelist and more (Richard W.M. Jones)
  * Basic 'New VM' wizard support for LXC guests
  * Remote serial console access (with latest libvirt)
  * Remote URL guest installs (with latest libvirt)
  * Add Hardware: Support <filesystem> devices
  * Add Hardware: Support <smartcard> devices (Marc-André Lureau)
  * Enable direct interface selection for qemu/kvm (Gerhard Stenzel)
  * Allow viewing and changing disk serial number
- Update to virtinst 0.600.0
  * virt-install: Various improvements to enable LXC/container guests:
  * New --filesystem option for <filesystem> devices
  * New --init option for container <init> path
  * New --container option (similar to --paravirt or --hvm)
  * virt-install: Make --location remotely (with latest libvirt)
  * virt-install: New --smartcard option for <smartcard> devices
  * (Marc-André Lureau)
  * virt-install: New --numatune option for building guest <numatune> XML
  * virt-install: option to set --disk error_policy=
  * virt-install: option to set --disk serial=
* Mon Aug 15 2011 carnold@novell.com
- Fix _do_show_create() to check for valid uri
* Mon Aug 15 2011 carnold@novell.com
- bnc#712214 - virt-manager 0.8.7 declared LGPL-2.1+ but is GPL-2.0+
* Fri Aug 12 2011 carnold@novell.com
- Fixes to desktop file to be more descriptive
* Wed Jul 20 2011 carnold@novell.com
- Fix gconf_schemas_prereq in virt-manager.spec file
* Mon Jul 18 2011 carnold@novell.com
- KVM: Add support for the qed file format
* Fri Jul 15 2011 carnold@novell.com
- KVM now supports the eepro100.  Add support in virt-manager for
  this nic
  virtman-eepro100.diff
* Fri Jul  8 2011 carnold@novell.com
- Upstream fixes
  virtman-fix-storage_capable.diff
  virtman-fix-ui-resize.diff
  virtman-fix-type.diff
  virtman-fix-addhw-nonhotplug.diff
  virtman-fix-no-nic-present.diff
  virtman-fix-ui-cleanup.diff
* Mon Apr  4 2011 carnold@novell.com
- Update to virt-manager 0.8.7
  * Allow renaming an offline VM
  * Spice password support (Marc-André Lureau)
  * Allow editting NIC <virtualport> settings (Gerhard Stenzel)
  * Allow enabling/disabling individual CPU features
  * Allow easily changing graphics type between VNC and SPICE for existing VM
  * Allow easily changing network source device for existing VM
- Update to virtinst 0.500.6
  * virt-install: --graphics spice now enables spicevmc and qxl
  * virt-install: New --disk parameter io=native|threads
* Wed Mar 23 2011 carnold@novell.com
- bnc#681908 - Virtualization/virt-manager: Bug
  virtman-connect-consoles-fix.diff
* Mon Mar 21 2011 carnold@novell.com
- Update to virt-manager 0.8.6
  * SPICE support (requires spice-gtk) (Marc-André Lureau)
  * Option to configure CPU model
  * Option to configure CPU topology
  * Save and migration cancellation (Wen Congyang)
  * Save and migration progress reporting
  * Option to enable bios boot menu
  * Option to configure direct kernel/initrd boot
- Update to virtinst 0.500.5
  * New virt-install --cpu option for configuring CPU
    model/features
  * virt-install --vcpus option can not specify topology and
    maxvcpus
  * New virt-install --graphics option to unify --vnc, --sdl,
    spice config
  * New virt-install --print-xml option to skip install and print
    XML
* Tue Jan 18 2011 carnold@novell.com
- bnc#657272 - virt-manager creates default 'dir' storage pool in
  /var/lib/libvirt/images on xen host
  virtman-storage-pool.diff
* Fri Jan  7 2011 carnold@novell.com
- bnc#641977 - virt-manager can't create kvm virtual Machines on a
  remote host.
* Mon Dec 20 2010 carnold@novell.com
- When installing remote, use virtinst
* Fri Oct 22 2010 seife@opensuse.org
- fix up previous commit that broke the patch
- fix runtime dependency on python-vte
* Thu Oct 21 2010 carnold@novell.com
- bnc#647261 - Get lot's of error in .xsession-errors when lauching
  yast
* Mon Sep 27 2010 seife@opensuse.org
- fix instant segfault with python 2.7, bnc#641981, patch taken
  from https://bugzilla.redhat.com/show_bug.cgi?id=620216
* Tue Sep 14 2010 seife@opensuse.org
- fix build on FACTORY after gconf2 and python changes
* Tue Aug 31 2010 carnold@novell.com
- Update to virt-manager 0.8.5
  * Improved save/restore support
  * Option to view and change disk cache mode
  * Configurable VNC keygrab sequence (Michal Novotny)
- Update to virtinst 0.500.4
  * New virt-install --console option for specifying virtio console
    device
  * New virt-install --channel option for specifying guest
    communication channel
  * New virt-install --boot option. Allows setting post-install boot
    order, direct kernel/initrd boot, and enabling boot device menu.
  * New virt-install --initrd-inject option, which enables
    installation using a _local_ kickstart file (Colin Walters)
* Wed Jul 28 2010 carnold@novell.com
- bnc#624250 - L3: virt-manager doesn't update "Autostart" setting
  in vm configuration correctly
  virtman-autorestart.diff
* Fri Jun 25 2010 jfehlig@novell.com
- bnc#611023 - Use netcat-openbsd, which contains proper 'nc'
  program
* Tue May 11 2010 seife@opensuse.org
- fix virt-{clone,convert,image,install} by installing the python
  libs into the proper directories
* Wed May  5 2010 carnold@novell.com
- bnc#602775 - An icon lost in "virt-manager"
  virtman-icon.diff
* Mon Apr 26 2010 carnold@novell.com
- Fixes in virtman-keycombo.diff to match virt-viewer's 'Send Key'
  menu options.  See bnc#553633
* Mon Apr 19 2010 carnold@novell.com
- bnc#597235 - virt-manager does not start complaining about a
  broken icon.
* Wed Mar 31 2010 carnold@novell.com
- bnc#592538 - VM status is recognized as "Shutoff" in virt-manager
  and virt-viewer after creating a snapshot.
* Fri Mar 26 2010 carnold@novell.com
- Update to virt-manager 0.8.4
  * Import install option: create a VM using an existing OS image
  * Support multiple boot devices and boot order
  * Watchdog device support
  * Enable setting a human readable VM description.
  * Option to manually specifying a bridge name, if bridge isn't
    detected
- Update to virtinst 0.500.3
  * virt-install: New --watchdog option: configure a virtual
    watchdog dev
  * virt-install: New --soundhw option: More flexible sound
    configuration deprecates --sound, though back compat is
    maintained
  * virt-install: New --security option: configure VM security
    driver
  * virt-install: New --description option: set a human readable
    desc
  * Better OS defaults: Use <video> VGA and <sound> AC97 if
    support
* Tue Mar 23 2010 carnold@novell.com
- Enable the following utilities.  Submitted by Stephan Kleine
  (bitdealer@gmail.com)
  virt-clone
  virt-convert
  virt-image
  virt-install
  virt-manager
* Thu Mar 18 2010 carnold@novell.com
- bnc#588391 - Send Key in virt-viewer does not work with Netware
  VM's
* Wed Mar 17 2010 carnold@novell.com
- Don't automatically connect to xen in the virt-manager.desktop
  file.  This results in an error dialog when only KVM is installed
* Mon Mar 15 2010 carnold@novell.com
- bnc#588215 - virt-manager/vminstall can't install new KVM Guests
* Fri Mar  5 2010 jfehlig@novell.com
- bnc#585990 - Fix add/remove device for active Xen guests.
  virtman-device-flags.diff
* Tue Feb 23 2010 jsong@novell.com
- virtinst-storage-ocfs2.diff (Xin Wei Hu)
  * add ocfs2 to  pool of dir (Filesystem Directory) type in libvirt
* Mon Feb 15 2010 chris@computersalat.de
- cleanup spec
  * norootforbuild
  * sort TAGS
- some rpmlint stuff
  * configfile
* Wed Feb 10 2010 carnold@novell.com
- Update to virt-manager version 0.8.3
  * New ability to manage network interfaces: start, stop, and view
    existing interfaces. Provision new bridge, bond, and vlan
    devices.
  * New option to 'customize VM before install', which allows
    adjusting most VM options from the install wizard.
- Update to virtinst version 0.500.2
  * virt-install: New option --autostart for setting domain
    autostart flag
  * virt-install: Allow specifying --host-device with lsusb and
    lspci format (0x1234:0x5678 for USB, etc)
  * virtinst: New 'Interface' module for building libvirt
    interface XML
* Thu Jan  7 2010 carnold@novell.com
- Update to virt-manager version 0.8.2
  * Right click in the manager window operates on the clicked row,
    NOT the last selected row. This could cause an admin to
    accidentally shut down the wrong machine.
  * Running virt-manager on a new machine / user account no longer
    produces a traceback.
  * Allow ejecting and connecting floppy media
* Fri Dec 11 2009 carnold@novell.com
- First time running virt-manager throws exception in engine.py
  add_connection().
  virtman-autoconnect.diff
* Thu Dec  3 2009 carnold@novell.com
- Update to virt-manager version 0.8.1
  * VM Migration wizard, exposing various migration options
  * Enumerate CDROM and bridge devices on remote connections
  * Can once again list multiple graphs in main manager window (Jon Nordby)
  * Support disabling dhcp (Michal Novotny), and specifying 'routed' type for new virtual networks
  * Support storage pool source enumeration for LVM, NFS, and SCSI
  * Allow changing VM ACPI, APIC, clock offset, individual vcpu pinning, and video model (vga, cirrus, etc.)
  * Many improvements and bugfixes
* Wed Nov 11 2009 carnold@novell.com
- bnc#552785 - virt-manager cannot connect to xend when started
  from an ordinary user's X session
  virtman-desktop.diff
* Tue Nov 10 2009 carnold@novell.com
- bnc#553633 - Update breaks menu access keys in virt-viewer and
  still misses some key sequences.
  This is a SLE10 bug fixed for the virt-manager viewer in all
  versions.
  virtman-keycombo.diff
* Wed Oct  7 2009 carnold@novell.com
- Added upstream bug fix.
  1262-vcpu-hotplug-fix.patch
* Mon Sep 21 2009 carnold@novell.com
- Added upstream bug fixes.
  1240-cdrom-driver-name.patch
  1242-delete-active-vm.patch
  1243-syntax-typo.patch
  1245-storage-browser-selection.patch
  1248-libvirt-connection.patch
* Fri Aug 28 2009 carnold@novell.com
- Building for 11.1 or sles11 fails because of changes in the
  schemas location.  Fix spec file to handle it.
* Thu Jul 30 2009 carnold@novell.com
- Update to virt-manager version 0.8.0
* Fri Jun 12 2009 carnold@novell.com
- Fixed build issue with virt-manager.schemas location.
- Changed .gz files to .bz2 files to save space and quiet RPMLINT
* Wed May 13 2009 dpmerrill@novell.com
- Use "graphics listen" for vnc connection (bnc#436629)
* Thu Apr 30 2009 dpmerrill@novell.com
- Add dbus-1-x11 dependency for minimal installations
* Tue Apr 21 2009 dpmerrill@novell.com
- Update to virt-manager-0.7.0 and virtinst-0.400.3
  Improved KVM support
  Added support for libvirt storage/network pools
  Details and Console windows are combined
  Added scaling for VM console window
  Simple VM migration support
* Sun Mar  1 2009 ro@suse.de
- move sr@Latn to sr@latin
* Fri Jan 23 2009 dpmerrill@novell.com
- Remove unsupported SCSI disk option (bnc#464293)
- Change cdrom start node to hdc instead of hdb (bnc#376935)
* Wed Dec  3 2008 dpmerrill@suse.de
- Remove ia64 from build architectures  (bnc#455989)
* Tue Nov 11 2008 dpmerrill@novell.com
- Add Requires python-urlgrabber for non Xen installations
- Change transport from nc to netcat for ssh connections
* Mon Nov  3 2008 dpmerrill@novell.com
- Add Requires librsvg for minimal template
* Wed Sep 10 2008 ro@suse.de
- fix build
* Thu May 22 2008 dpmerrill@novell.com
- (bnc#383979) add vm-install to Requires section
* Fri May 16 2008 ro@suse.de
- move python install to install section in specfile
- fix build without root privileges
* Tue Apr 29 2008 dpmerrill@novell.com
- Corrected gconf calls in spec file to fix build errors
* Tue Apr 29 2008 dpmerrill@novell.com
- Added needsrootforbuild to spec file to fix build errors
* Fri Apr 25 2008 dpmerrill@novell.com
- Fixed SendKey "PrintScreen" option
* Thu Apr 24 2008 dpmerrill@novell.com
- Added python-gtk-devel and python-gobject2-devel to spec file
  to reflect changes in OpenSuse11.0
* Tue Apr 22 2008 dpmerrill@novell.com
- Changed desktop file for starting from KDE (bnc#377277)
* Mon Apr 21 2008 dpmerrill@novell.com
- Changed "SendKey" to send "Delete" instead of "Del" (bnc#381897)
* Fri Apr 18 2008 dpmerrill@novell.com
- Added vncViewerMaxRetries to prevent showing expected libvirt
  exceptions from cluttering the error log (bnc#366792)
* Wed Apr  9 2008 dpmerrill@novell.com
- Changed vnc settings to prevent screen-saver lockup (bnc#253264)
- Added read-only option in Details->Hardware for adding cdroms
  to prevent libvirt exceptions. (bnc#368204) (bnc#361990)
* Fri Apr  4 2008 dpmerrill@novell.com
- Removed Virtual Network tab from host details page (bnc#364514)
* Wed Apr  2 2008 dpmerrill@novell.com
- Fixed adding a virtual network to a vm (bnc#302663)
  Also fixed errors caused by new dbus-1 release
* Wed Mar 12 2008 dpmerrill@novell.com
- Added warning for attempting multiple installs (bnc#368278)
* Wed Feb 20 2008 dpmerrill@novell.com
- Added virtman-timewatch to minimize window after
- inactivity to work around memory leaks in GTK and DBus
- bnc#287366 (L3)
* Thu Feb 14 2008 dpmerrill@novell.com
- Changed virtman-xen-uri to correct the case where no
- connection param is passed in and uri is None
- bnc#362013
* Tue Feb 12 2008 dpmerrill@novell.com
- Changed virtman-desktop and virtman-xen-uri to correct invalid
- parms being passed in from YaST - now sends "-c xen:///"
- bnc#361334
* Tue Feb 12 2008 dpmerrill@novell.com
- Added virtman-detect to delay Hal signal connection until
- after device detection to prevent start-up delay
- bnc#361202
* Mon Feb 11 2008 dpmerrill@novell.com
- Added virtman-pointer to set vnc to show only one pointer
- bnc#359799
* Sun Feb  3 2008 dpmerrill@novell.com
- Added virtman-vminstall for connecting to vm-install
- and changed virtman-xen-uri.diff to force "xen:///"
- bnc#358400
* Sun Feb  3 2008 dpmerrill@novell.com
- Added virtman-xen-uri.diff to fix problem starting vnc.
- virtman was getting confused between "xen" and "xen:///" uris.
- bnc#358397
* Sat Feb  2 2008 dpmerrill@novell.com
- Added virtman-dbus-query.diff to work around a hal/dbus
- bug that crashes on QueryCapabilities()
- bnc#358324
* Thu Jan 31 2008 dpmerrill@novell.com
- Added virtinst to finish resolving run-time dependencies
- bnc#355826
- bnc#356999
* Wed Jan 23 2008 dpmerrill@novell.com
- Changed package requirements in spec file Requires section.
- pygtk2 -> python-gtk
- gnome-python2-gconf -> python-gnome
- dbus-python -> dbus-1-python
- gnome-python2-gnomekeyring -> removed
- gnome-python2-gnomevfs -> removed
- python-virtinst -> removed
- pygtk2-libglade -> removed
- gtk-vnc-python -> python-gtk-vnc
* Sat Jan 19 2008 dpmerrill@novell.com
- Added new virt-manager version (0.5.3) to sle10-sp2-i386
- (FATE Feature #302140)
* Thu Aug 16 2007 ccoffing@novell.com
- Update virt-manager to match vm-install changes due to #279153.
* Mon Jul  9 2007 ccoffing@novell.com
- Properly attach and detach CDs to running VM.  (#289393)
* Wed May  9 2007 ccoffing@novell.com
- Update .desktop with proper group.  (#258600)
* Fri May  4 2007 ccoffing@novell.com
- Fix syntax error ("NOne" should be "None"), which caused
  unnecessary VNC connection failures in virt-manager.  (#237406)
* Wed May  2 2007 ccoffing@novell.com
- Drop virtman-xenstored-thrashing.diff, to change the default
  refresh rate from 5 seconds back to 1 second.  It is more
  important to have up-to-date knowledge of VMs (to ensure consoles
  can be opened, etc) rather than trying to lessen virt-manager's
  processor load.  (#270761)
* Tue Apr 10 2007 ccoffing@novell.com
- Remove code that (incorrectly) guesses the vnc port.  (#259692)
- Do not refresh GUI every second (which causes xenstored to not
  thrash so badly, which makes virt-manager more responsive and
  less likely to time out or lock up).  Partial fix for #237406.
- Import changeset 440, which makes virt-manager honor dom0's
  keymap.  (#241149)
- Revert patch for bug #244772, because it causes lockups, as
  noted in bug #261110.
- Fix attaching disks to running VM.  (#238986)
* Wed Mar 28 2007 ccoffing@novell.com
- Update icon filename.
* Tue Mar 13 2007 ccoffing@novell.com
- Import threading and timer tick patches from upstream to improve
  stability. (#237406 and others)
- Do not offer QEMU option. (#254083)
* Mon Mar 12 2007 ccoffing@novell.com
- Update virt-manager to match changes in vm-install's disk class,
  due to bug #247849.
* Fri Mar  9 2007 ccoffing@novell.com
- Make Ctrl+Alt release the mouse cursor (#252998).
* Thu Mar  8 2007 ccoffing@novell.com
- Add release to "Requires: xen-tools", to prevent mixing with
  pre-beta 5.  (#238986, #252495)
* Fri Mar  2 2007 ccoffing@novell.com
- Disable gtk-menu-bar-accel when VM has focus, to allow VM to get
  F10 key. (#240001)
* Tue Feb 27 2007 ccoffing@novell.com
- Update to 0.3.1.
- "Requires: librsvg" (#250156)
- Re-use vm-install's disk UI, to allow disks to be added/removed
  from xend-managed VMs (currently only for running VMs). (#238986)
* Thu Feb 22 2007 ccoffing@novell.com
- If Xen isn't running, put up error window instead of raising.
  (#244772)
* Tue Feb 13 2007 ccoffing@novell.com
- Update to latest hg; grabs mouse for better mouse tracking.
  (#240387)
- Don't lose mouse grab on every keystroke
- Disable menubar & toolbar when pointer is in VM window, to avoid
  key conflicts.  (#240001)
- Fix syntax to avoid deprecation warnings (don't raise strings).
- YaST integration: default to managing on-box; detach from yast
  control center.
* Mon Jan 29 2007 ccoffing@novell.com
- Fix desktop file.  (#239275)
- Update to 0.3.0 (updated translations; no code changes)
* Mon Jan 22 2007 ccoffing@novell.com
- Fix desktop file, so icon shows in YaST.  (#237046)
- Clean up macros in spec file.
* Fri Jan 19 2007 ccoffing@novell.com
- Use temporary icon until real ones arrive.
- Update to changeset 371 to fix VNC issues.
* Wed Jan 17 2007 ccoffing@novell.com
- Fix BuildRequires and paths to work with both SLES10 and STABLE.
* Fri Jan 12 2007 ccoffing@novell.com
- Fix sysconfdir path.
- Add desktop file.
* Thu Jan 11 2007 ccoffing@novell.com
- Add to SLES 10 SP1 (fate #301181)
- Update to virt-manager 0.2.6.
- Fix type_register deprecation warnings.
* Tue Oct 24 2006 ccoffing@novell.com
- Initial package.
- Replace virt-inst with xen-vm-install (part of xen-tools-install)
